@@ -1,5 +1,3 @@
-# coding=utf-8
-
 from Acquisition import aq_base
 from euphorie.client.browser.webhelpers import WebHelpers
 from euphorie.client.country import IClientCountry
@@ -7,8 +5,10 @@ from euphorie.client.country import IClientCountry
 
 class ClientView(WebHelpers):
     def __call__(self):
-        """The frontpage has been disbanded. We redirect to the country that
-        is defined as the default, or pick a random country.
+        """The frontpage has been disbanded.
+
+        We redirect to the country that is defined as the default, or
+        pick a random country.
         """
         target = None
         language = self.request.form.get("language")
@@ -25,4 +25,4 @@ class ClientView(WebHelpers):
                     break
         if not target:
             return "No country was identified"
-        self.request.RESPONSE.redirect("{}{}".format(target.absolute_url(), url_param))
+        self.request.RESPONSE.redirect(f"{target.absolute_url()}{url_param}")
