@@ -1,4 +1,3 @@
-# coding=utf-8
 from Acquisition import aq_inner
 from anytree import NodeMixin
 from anytree.node.util import _repr
@@ -18,17 +17,16 @@ from Products.CMFPlone.utils import safe_unicode
 from Products.Five import BrowserView
 from z3c.saconfig import Session
 from zExceptions import Unauthorized
+from zope.deprecation import deprecate
 from zope.interface import directlyProvides
 
-import six
-
 
 logger = getLogger(__name__)
 
 
 def capitalize(text):
     if text:
-        return "{0}{1}".format(text[0].upper(), text[1:])
+        return f"{text[0].upper()}{text[1:]}"
 
 
 class Node(NodeMixin):
@@ -39,19 +37,18 @@ class Node(NodeMixin):
 
     @property
     def groups(self):
-        """Assume childrens are groups and return them sorted by title"""
+        """Assume childrens are groups and return them sorted by title."""
         return sorted(self.children, key=lambda x: x.title)
 
     @property
     def sessions(self):
-        """Assume childrens are sessions and return them sorted by
-        reversed modification date
-        """
+        """Assume childrens are sessions and return them sorted by reversed
+        modification date."""
         return sorted(self.children, key=lambda x: x.context.modified, reverse=True)
 
     @property
     def survey_templates(self):
-        """Return all children that are survey_templates, sorted by title"""
+        """Return all children that are survey_templates, sorted by title."""
         return sorted(
             (item for item in self.children if item.type == "survey_template"),
             key=lambda x: x.title.lower(),
@@ -59,7 +56,7 @@ class Node(NodeMixin):
 
     @property
     def categories(self):
-        """Return all children that are categories, sorted by title"""
+        """Return all children that are categories, sorted by title."""
         return sorted(
             (item for item in self.children if item.type == "category"),
             key=lambda x: x.title,
@@ -73,7 +70,7 @@ class Node(NodeMixin):
         return _repr(self, args=args, nameblacklist=["context"])
 
 
-class SurveyTemplatesMixin(object):
+class SurveyTemplatesMixin:
     # switch from radio buttons to dropdown above this number of tools
     # Note: since there's a CSS glitch with displaying radio buttons, we always
     # show the the dropdown
@@ -139,18 +136,17 @@ class SurveyTemplatesMixin(object):
                 if getattr(survey, "obsolete", False):
                     continue
                 categories = getattr(survey, "tool_category", None)
-                id = "%s/%s" % (sector.id, survey.id)
+                id = f"{sector.id}/{survey.id}"
                 if not isinstance(categories, list):
                     categories = [categories]
                 if not categories:
                     categories = ["None"]
                 for category in categories:
                     survey_items.append((category, survey, id))
-        return sorted(survey_items, key=lambda x: (x[0], x[1].title))
+        return sorted(survey_items, key=lambda x: (x[0] or "None", x[1].title))
 
 
 class SessionsView(BrowserView, SurveyTemplatesMixin):
-
     variation_class = "variation-dashboard"
     form_action_name = "dashboard-switcher"
 
@@ -195,7 +191,7 @@ class SessionsView(BrowserView, SurveyTemplatesMixin):
     @property
     @memoize_contextless
     def account(self):
-        """The currently authenticated account"""
+        """The currently authenticated account."""
         return get_current_account()
 
     def _updateSurveys(self):
@@ -218,7 +214,7 @@ class SessionsView(BrowserView, SurveyTemplatesMixin):
                     and not survey.language.strip().startswith(language)
                 ):
                     continue
-                info = {"id": "%s/%s" % (sector.id, survey.id), "title": survey.title}
+                info = {"id": f"{sector.id}/{survey.id}", "title": survey.title}
                 if getattr(survey, "obsolete", False):
                     # getattr needed for surveys which were published before
                     # the obsolete flag added.
@@ -245,22 +241,17 @@ class SessionsView(BrowserView, SurveyTemplatesMixin):
         survey_view = api.content.get_view("index_html", survey, self.request)
         survey_session = survey_view.create_survey_session(title, account)
         self.request.response.redirect(
-            "{base_url}/++session++{session_id}/@@start"
-            "?initial_view=1&new_session=1".format(
-                base_url=survey.absolute_url(), session_id=survey_session.id
-            )
+            f"{survey_session.absolute_url()}/@@start?initial_view=1&new_session=1"
         )
 
     def _ContinueSurvey(self, info):
         """Utility method to continue an existing session."""
         session = Session.query(self.survey_session_model).get(info["session"])
-        survey = self.request.client.restrictedTraverse(str(session.zodb_path))
         extra = ""
         if info.get("new_clone", None):
             extra = "&new_clone=1"
         self.request.response.redirect(
-            "%s/++session++%s/@@resume?initial_view=1%s"
-            % (survey.absolute_url(), session.id, extra)
+            f"{session.absolute_url()}/@@resume?initial_view=1{extra}"
         )
 
     def tool_byline(self):
@@ -288,11 +279,11 @@ class SessionsView(BrowserView, SurveyTemplatesMixin):
         elif action == "continue":
             return self._ContinueSurvey(reply)
         self._updateSurveys()
-        return super(SessionsView, self).__call__()
+        return super().__call__()
 
 
 class SessionBrowserNavigator(BrowserView):
-    """Logic to build the navigator for the sessions"""
+    """Logic to build the navigator for the sessions."""
 
     no_splash = True
 
@@ -318,7 +309,7 @@ class SessionBrowserNavigator(BrowserView):
 
     @memoize
     def get_root_group(self, groupid=None):
-        """Return the group that is the root of the navigation tree"""
+        """Return the group that is the root of the navigation tree."""
         if not groupid:
             groupid = self.groupid
         if not groupid:
@@ -331,16 +322,14 @@ class SessionBrowserNavigator(BrowserView):
     @property
     @memoize
     def searchable_text(self):
-        """Return the text we need to search in postgres
-        already surrounded with '%'
-        Allow a minimum size of 3 characters to reduce the load.
-        """
+        """Return the text we need to search in postgres already surrounded
+        with '%' Allow a minimum size of 3 characters to reduce the load."""
         searchable_text = self.request.get("SearchableText")
-        if not isinstance(searchable_text, six.string_types):
+        if not isinstance(searchable_text, str):
             return ""
         if len(searchable_text) < 3:
             return ""
-        return "%{}%".format(safe_unicode(searchable_text))
+        return f"%{safe_unicode(searchable_text)}%"
 
     @memoize
     def leaf_groups(self, groupid=None):
@@ -351,14 +340,14 @@ class SessionBrowserNavigator(BrowserView):
 
     @memoize
     def leaf_sessions(self):
-        """The sessions we want to display in the navigation"""
+        """The sessions we want to display in the navigation."""
         query = self.webhelpers.get_sessions_query(
             context=self.webhelpers.country_obj, searchable_text=self.searchable_text
         )
         return query.all()
 
     def has_content(self):
-        """Checks if we have something meaningfull to display"""
+        """Checks if we have something meaningfull to display."""
         if len(self.leaf_groups()):
             return True
         if len(self.leaf_sessions()):
@@ -373,7 +362,6 @@ class Assessments(BrowserView):
         return api.content.get_view("webhelpers", self.context, self.request)
 
     @property
-    @memoize
     def form_action_name(self):
         return self.__name__
 
@@ -381,17 +369,49 @@ class Assessments(BrowserView):
     def template(self):
         return self.index
 
+    @property
+    def organisation_options(self):
+        organisation_view = api.content.get_view(
+            "organisation", self.context, self.request
+        )
+        return [
+            {
+                "label": organisation.title,
+                "value": organisation.owner_id,
+                "selected": "selected"
+                if str(organisation.owner_id) == self.request.get("organisation", "")
+                else None,
+            }
+            for organisation in organisation_view.organisations
+        ]
+
+    def is_filter_active(self):
+        """True if any filters in the request parameters are different from the
+        defaults."""
+        return (
+            self.request.get("organisation")
+            or self.request.get("sort_on", "alphabetical") != "alphabetical"
+        )
+
     @property
     @memoize
     def sessions(self):
         searchable_text = self.request.get("SearchableText", None)
         if searchable_text and "%" not in searchable_text:
-            searchable_text = "%{}%".format(searchable_text)
+            searchable_text = f"%{searchable_text}%"
+        sort_on_value = self.request.get("sort_on", "alphabetical")
+        if sort_on_value == "alphabetical":
+            order_by = self.webhelpers.survey_session_model.title
+        else:
+            order_by = False
+        organisation_value = self.request.get("organisation", "")
         return self.webhelpers.get_sessions_query(
             context=self.context,
             searchable_text=searchable_text,
             include_archived=True,
-        ).all()
+            filter_by_account=organisation_value or True,
+            order_by=order_by,
+        )
 
 
 class Surveys(BrowserView, SurveyTemplatesMixin):
@@ -499,7 +519,7 @@ class Surveys(BrowserView, SurveyTemplatesMixin):
         utils.setLanguage(
             self.request, self.context, getattr(self.context, "language", None)
         )
-        return super(Surveys, self).__call__()
+        return super().__call__()
 
 
 class PortletBase(BrowserView):
@@ -540,6 +560,8 @@ class PortletBase(BrowserView):
 
 
 class MyRAsPortlet(PortletBase):
+    element_id = "portlet-my-risk-assessments"
+
     @property
     def columns(self):
         if self.surveys:
@@ -548,7 +570,7 @@ class MyRAsPortlet(PortletBase):
 
     @property
     def assessments_list_macro(self):
-        """Get the listing macro from the assessments template"""
+        """Get the listing macro from the assessments template."""
         request = self.request.clone()
         # This is needed, since the view might be subclassed and therefore
         # associated with a different skin-layer.
@@ -559,10 +581,8 @@ class MyRAsPortlet(PortletBase):
     @property
     @memoize_contextless
     def hide_archived(self):
-        """By default we hide the archived session and
-        we have a checkbox that shows with a sibling
-        hide_archived_marker input field
-        """
+        """By default we hide the archived session and we have a checkbox that
+        shows with a sibling hide_archived_marker input field."""
         if self.request.get("hide_archived_marker"):
             if not self.request.get("hide_archived"):
                 return False
@@ -570,8 +590,18 @@ class MyRAsPortlet(PortletBase):
 
     @property
     @memoize
+    def organisation_view(self):
+        """Get the organisation view to reuse its methods."""
+        return api.content.get_view("organisation", self.context, self.request)
+
+    @property
+    @memoize
+    @deprecate(
+        "Replace with self.sessions_by_organisation (which is a dict), "
+        "deprecated in version 14.2"
+    )
     def sessions(self):
-        """We want the archived sessions"""
+        """We want the archived sessions."""
         return (
             self.webhelpers.get_sessions_query(
                 context=self.context, include_archived=not self.hide_archived
@@ -580,6 +610,40 @@ class MyRAsPortlet(PortletBase):
             .all()
         )
 
+    @property
+    @memoize
+    def sessions_by_organisation(self):
+        """Return the sessions grouped by organisation."""
+        base_query = self.webhelpers.get_sessions_query(
+            context=self.context, include_archived=not self.hide_archived
+        )
+
+        account_id_column = self.webhelpers.survey_session_model.account_id
+
+        sessions_by_organisation = []
+        known_owner_ids = set()
+        for organisation in self.organisation_view.organisations:
+            known_owner_ids.add(organisation.owner_id)
+            sessions = (
+                base_query.filter(account_id_column == organisation.owner_id)
+                .limit(5)
+                .all()
+            )
+            if sessions:
+                sessions_by_organisation.append((organisation, sessions))
+
+        account = self.webhelpers.get_current_account()
+        if not account.organisation:
+            sessions = (
+                base_query.filter(account_id_column.notin_(known_owner_ids))
+                .limit(5)
+                .all()
+            )
+            if sessions:
+                sessions_by_organisation.insert(0, (None, sessions))
+
+        return dict(sessions_by_organisation)
+
     @property
     def label_start_session(self):
         label = api.portal.translate(
@@ -589,5 +653,4 @@ class MyRAsPortlet(PortletBase):
 
 
 class AvailableToolsPortlet(PortletBase, SurveyTemplatesMixin):
-
-    pass
+    element_id = "portlet-available-tools"
