@@ -1,4 +1,3 @@
-# coding=utf-8
 """
 Report
 ------
@@ -17,8 +16,8 @@ from openpyxl.writer.excel import save_virtual_workbook
 from plone import api
 from plone.memoize.view import memoize
 from Products.Five import BrowserView
-from six.moves.urllib.parse import quote
 from sqlalchemy import sql
+from urllib.parse import quote
 from zope.i18n import translate
 
 import logging
@@ -69,9 +68,9 @@ class ActionPlanTimeline(BrowserView, survey._StatusHelper):
         return self.context.session
 
     def get_measures(self):
-        """Find all data that should be included in the report.
-           Re-use the helper methods from Status to compute the
-           filtered module paths and the relevant risks.
+        """Find all data that should be included in the report. Re-use the
+        helper methods from Status to compute the filtered module paths and the
+        relevant risks.
 
         The data is returned as a list of tuples containing a
         :py:class:`Module <euphorie.client.model.Module>`,
@@ -83,7 +82,7 @@ class ActionPlanTimeline(BrowserView, survey._StatusHelper):
         module_paths = self.getModulePaths()
         risk_data = self.getRisks(module_paths)
         measure_data = []
-        for (module, risk) in risk_data:
+        for module, risk in risk_data:
             action_plan_q = self.sql_session.query(model.ActionPlan).filter(
                 sql.and_(
                     model.ActionPlan.risk_id == risk.id,
@@ -167,13 +166,14 @@ class ActionPlanTimeline(BrowserView, survey._StatusHelper):
         )
         survey = self.context.aq_parent
 
-        for (column, (ntype, key, title)) in enumerate(self.columns):
+        for column, (ntype, key, title) in enumerate(self.columns):
             sheet.cell(row=1, column=column + 1).value = translate(
                 title, context=self.request
             )
 
+        portal_transforms = api.portal.get_tool("portal_transforms")
         row = 2
-        for (module, risk, measure) in self.get_measures():
+        for module, risk, measure in self.get_measures():
             if risk.identification in ["n/a", "yes"]:
                 continue
 
@@ -182,10 +182,12 @@ class ActionPlanTimeline(BrowserView, survey._StatusHelper):
                 zodb_node = None
             else:
                 zodb_node = survey.restrictedTraverse(risk.zodb_path.split("/"))
-            for (ntype, key, title) in self.columns:
+            for ntype, key, title in self.columns:
                 value = None
                 if ntype == "measure":
                     value = getattr(measure, key, None)
+                    if key == "action" and value:
+                        value = portal_transforms.convertToData("text/plain", value)
                 elif ntype == "risk":
                     value = getattr(risk, key, None)
                     if key == "priority":
