@@ -1,12 +1,11 @@
-# coding=utf-8
 from Acquisition import aq_inner
-from Acquisition import aq_parent
 from collections import defaultdict
 from datetime import datetime
 from decimal import Decimal
 from euphorie import MessageFactory as _
 from euphorie.client import config
 from euphorie.client import utils
+from euphorie.client.adapters.json import SAJsonEncoder
 from euphorie.client.model import ACTION_PLAN_FILTER
 from euphorie.client.model import ActionPlan
 from euphorie.client.model import get_current_account
@@ -44,6 +43,7 @@ from zope.event import notify
 from zope.i18n import translate
 from zope.lifecycleevent import ObjectModifiedEvent
 
+import json
 import re
 
 
@@ -54,10 +54,10 @@ except ImportError:
 
 
 def sql_clone(obj, skip={}, session=None):
-    """Clone a sql object avoiding the properties in the skip parameter
+    """Clone a sql object avoiding the properties in the skip parameter.
 
-    The skip parameter is optional but you probably want to always pass the
-    primary key
+    The skip parameter is optional but you probably want to always pass
+    the primary key
     """
     # Never copy the _sa_instance_state attribute
     skip.add("_sa_instance_state")
@@ -94,11 +94,12 @@ class IStartFormSchema(model.Schema):
     )
 
 
-class SessionMixin(object):
-    """Mostly properties we want to reuse for the views in the context of a session"""
+class SessionMixin:
+    """Mostly properties we want to reuse for the views in the context of a
+    session."""
 
     def update(self):
-        super(SessionMixin, self).update()
+        super().update()
         utils.setLanguage(self.request, self.survey, self.survey.language)
 
     @property
@@ -109,7 +110,7 @@ class SessionMixin(object):
     @property
     @memoize
     def survey(self):
-        """This is the survey dexterity object"""
+        """This is the survey dexterity object."""
         return self.webhelpers._survey
 
     @property
@@ -117,11 +118,6 @@ class SessionMixin(object):
     def session(self):
         return self.context.session
 
-    def is_new_session(self):
-        if self.request.get("new_session"):
-            return True
-        return self.session.children().count() == 0
-
     @property
     @memoize
     def has_profile(self):
@@ -174,7 +170,8 @@ class Start(SessionMixin, AutoExtensibleForm, EditForm):
 
     @memoize
     def get_pat_messages_above_title(self):
-        """List of messages we want to display above the risk assesment title"""
+        """List of messages we want to display above the risk assesment
+        title."""
         if not self.webhelpers.can_edit_session:
             link_download_section = _(
                 "no_translate_link_download_section",
@@ -193,7 +190,8 @@ class Start(SessionMixin, AutoExtensibleForm, EditForm):
 
     @memoize
     def get_pat_multiple_messages_below_article(self):
-        """List of messages we want to display under the risk assesment article
+        """List of messages we want to display under the risk assesment
+        article.
 
         Those messages should be iterable.
         Example of a good returned value::
@@ -203,7 +201,6 @@ class Start(SessionMixin, AutoExtensibleForm, EditForm):
                 (message2a, message2),
                 ...
             ]
-
         """
         return []
 
@@ -217,7 +214,7 @@ class Start(SessionMixin, AutoExtensibleForm, EditForm):
     def update(self):
         self.verify_view_permission()
         utils.setLanguage(self.request, self.survey, self.survey.language)
-        super(Start, self).update()
+        super().update()
         if self.request.method != "POST":
             return
 
@@ -270,7 +267,7 @@ class Profile(SessionMixin, AutoExtensibleForm, EditForm):
         """
         profile = {}
         form = self.request.form
-        for (id, answer) in form.items():
+        for id, answer in form.items():
             match = self.id_patt.match(id)
             if match:
                 id = match.group(1)
@@ -282,11 +279,11 @@ class Profile(SessionMixin, AutoExtensibleForm, EditForm):
                 # is repeatable
                 if match:
                     continue
-                if not form.get("pq{0}.present".format(id), "") == "yes":
+                if not form.get(f"pq{id}.present", "") == "yes":
                     continue
                 if isinstance(answer, list):
                     profile[id] = list(filter(None, (a.strip() for a in answer)))
-                    if form.get("pq{0}.multiple".format(id), "") != "yes":
+                    if form.get(f"pq{id}.multiple", "") != "yes":
                         profile[id] = profile[id][:1]
                 else:
                     profile[id] = answer
@@ -327,8 +324,15 @@ class Profile(SessionMixin, AutoExtensibleForm, EditForm):
             # Touch means: the modification timestamp is set.
             # But we need to make sure the refreshed marker is up to date!
             survey_session.refresh_survey(survey)
-            return survey_session
+            new_session = survey_session
+        else:
+            new_session = self.rebuild_session(survey, profile)
 
+        new_session.update_measure_types(survey)
+        return new_session
+
+    def rebuild_session(self, survey, profile):
+        survey_session = self.session
         params = {}
         # Some values might not be present, depending on the type of survey session
         _marker = object()
@@ -410,22 +414,18 @@ class Profile(SessionMixin, AutoExtensibleForm, EditForm):
         if not self.profile_questions or self.request.method == "POST":
             new_session = self.setupSession()
             self.request.response.redirect(
-                "{base_url}/++session++{session_id}/{target}".format(
-                    base_url=self.context.aq_parent.absolute_url(),
-                    session_id=new_session.id,
-                    target=self.next_view_name,
-                )
+                f"{new_session.absolute_url()}/{self.next_view_name}"
             )
 
 
 class Update(Profile):
-    """Update a survey session after a survey has been republished. If a
-    the survey has a profile the user is asked to confirm the current
-    profile before continuing.
+    """Update a survey session after a survey has been republished. If a the
+    survey has a profile the user is asked to confirm the current profile
+    before continuing.
 
-    The behaviour is exactly the same as the normal start page for a session
-    (see the :py:class:`Profile` view), but uses a different template with more
-    detailed instructions for the user.
+    The behaviour is exactly the same as the normal start page for a
+    session (see the :py:class:`Profile` view), but uses a different
+    template with more detailed instructions for the user.
     """
 
 
@@ -446,11 +446,11 @@ class Involve(SessionMixin, BrowserView):
             return self.request.response.redirect(self.webhelpers.client_url)
 
         utils.setLanguage(self.request, self.survey, self.survey.language)
-        return super(Involve, self).__call__()
+        return super().__call__()
 
 
 class ContentsPreview(BrowserView):
-    """A View for displaying the full contents of a tool and printing them
+    """A View for displaying the full contents of a tool and printing them.
 
     View name: @@contents-preview
     """
@@ -477,6 +477,7 @@ class ContentsPreview(BrowserView):
 
     def get_session_nodes(self):
         """Return an ordered list of all tree items for the current survey.
+
         By OSHA's request, optional submodules are always included.
         """
         query = (
@@ -508,9 +509,8 @@ class ContentsPreview(BrowserView):
             return self.zodb_node(node).description
 
     def get_legal_references(self, node):
-        """We might add some logic to never show legal references depending
-        on a setting per country / survey.
-        """
+        """We might add some logic to never show legal references depending on
+        a setting per country / survey."""
         zodb_node = self.zodb_node(node)
         if not zodb_node:
             return
@@ -598,7 +598,7 @@ class Identification(SessionMixin, BrowserView):
         # For the specific oira translation, we rewrite to "nl_BE"
         if "-" in lang:
             elems = lang.split("-")
-            lang = "{0}_{1}".format(elems[0], elems[1].upper())
+            lang = f"{elems[0]}_{elems[1].upper()}"
         return translate(
             _("extra_text_identification", default=""), target_language=lang
         )
@@ -620,11 +620,11 @@ class Identification(SessionMixin, BrowserView):
         if self.webhelpers.use_involve_phase:
             self.request.RESPONSE.redirect(self.next_url)
         else:
-            return super(Identification, self).__call__()
+            return super().__call__()
 
 
 class DeleteSession(SessionMixin, BrowserView):
-    """View name: @@delete-session"""
+    """View name: @@delete-session."""
 
     def __call__(self):
         if not self.webhelpers.can_delete_session:
@@ -643,7 +643,7 @@ class DeleteSession(SessionMixin, BrowserView):
 
 
 class ConfirmationDeleteSession(SessionMixin, BrowserView):
-    """View name: @@confirmation-delete-session"""
+    """View name: @@confirmation-delete-session."""
 
     no_splash = True
 
@@ -656,7 +656,7 @@ class ConfirmationDeleteSession(SessionMixin, BrowserView):
 
 
 class ConfirmationArchiveSession(SessionMixin, BrowserView):
-    """View name: @@confirmation-archive-session"""
+    """View name: @@confirmation-archive-session."""
 
     no_splash = True
 
@@ -669,7 +669,7 @@ class ConfirmationArchiveSession(SessionMixin, BrowserView):
 
 
 class ArchiveSession(SessionMixin, BrowserView):
-    """View name: @@archive-session"""
+    """View name: @@archive-session."""
 
     def notify_modified(self):
         notify(ObjectModifiedEvent(self.context.session))
@@ -694,7 +694,7 @@ class ArchiveSession(SessionMixin, BrowserView):
 
 
 class CloneSession(SessionMixin, BrowserView):
-    """View name: @@confirmation-clone-session"""
+    """View name: @@confirmation-clone-session."""
 
     def get_cloned_session(self):
         sql_session = Session
@@ -767,7 +767,7 @@ class CloneSession(SessionMixin, BrowserView):
         return new_session
 
     def clone(self):
-        """Clone this session and redirect to the start view"""
+        """Clone this session and redirect to the start view."""
         if not self.webhelpers.can_view_session:
             # The user cannot call this view to go the sessions overview.
             return self.request.response.redirect(self.webhelpers.client_url)
@@ -776,23 +776,21 @@ class CloneSession(SessionMixin, BrowserView):
         api.portal.show_message(
             _("The risk assessment has been cloned"), self.request, "success"
         )
-        target = "{contexturl}/++session++{sessionid}/@@start?new_clone=1".format(
-            contexturl=aq_parent(self.context).absolute_url(), sessionid=new_session.id
-        )
+        target = f"{new_session.absolute_url()}/@@start?new_clone=1"
         self.request.response.redirect(target)
 
     def __call__(self):
         if not self.webhelpers.can_view_session:
             # The user cannot call this view to go the sessions overview.
             return self.request.response.redirect(self.webhelpers.client_url)
-        return super(CloneSession, self).__call__()
+        return super().__call__()
 
 
 class PublicationMenu(SessionMixin, BrowserView):
     @property
     @memoize_contextless
     def portal(self):
-        """The currently authenticated account"""
+        """The currently authenticated account."""
         return api.portal.get()
 
     def redirect(self):
@@ -800,18 +798,18 @@ class PublicationMenu(SessionMixin, BrowserView):
         return self.request.response.redirect(target)
 
     def reset_date(self):
-        """Reset the session date to now"""
+        """Reset the session date to now."""
         session = self.context.session
         session.published = datetime.now()
         session.last_publisher = get_current_account()
         return self.redirect()
 
     def set_date(self):
-        """Set the session date to now"""
+        """Set the session date to now."""
         return self.reset_date()
 
     def unset_date(self):
-        """Unset the session date"""
+        """Unset the session date."""
         session = self.context.session
         session.published = None
         session.last_publisher = None
@@ -866,9 +864,8 @@ class ActionPlanView(SessionMixin, BrowserView):
         return self.webhelpers.country == "it"
 
     def __call__(self):
-        """Render the page only if the user has edit rights,
-        otherwise redirect to the start page of the session.
-        """
+        """Render the page only if the user has edit rights, otherwise redirect
+        to the start page of the session."""
         if not self.webhelpers.can_edit_session:
             return self.request.response.redirect(
                 self.context.absolute_url() + "/@@start"
@@ -880,7 +877,7 @@ class ActionPlanView(SessionMixin, BrowserView):
                 self.context.absolute_url() + "/@@report"
             )
         utils.setLanguage(self.request, self.survey, self.survey.language)
-        return super(ActionPlanView, self).__call__()
+        return super().__call__()
 
 
 class Report(SessionMixin, BrowserView):
@@ -909,14 +906,14 @@ class Report(SessionMixin, BrowserView):
 
             user = get_current_account()
             if getattr(user, "account_type", None) == config.GUEST_ACCOUNT:
-                url = "%s/@@register_session?came_from=%s" % (
+                url = "{}/@@register_session?came_from={}".format(
                     self.context.absolute_url(),
                     quote(url, ""),
                 )
             return self.request.response.redirect(url)
 
         utils.setLanguage(self.request, self.survey, self.survey.language)
-        return super(Report, self).__call__()
+        return super().__call__()
 
 
 class Status(SessionMixin, BrowserView, _StatusHelper):
@@ -942,12 +939,12 @@ class Status(SessionMixin, BrowserView, _StatusHelper):
         if "-" in lang:
             date_lang = lang.split("-")[0]
             elems = lang.split("-")
-            lang = "{0}_{1}".format(elems[0], elems[1].upper())
-        self.date = "{0} {1} {2}".format(
+            lang = f"{elems[0]}_{elems[1].upper()}"
+        self.date = "{} {} {}".format(
             now.strftime("%d"),
             translate(
                 PloneLocalesMessageFactory(
-                    "month_{0}".format(now.strftime("%b").lower()),
+                    "month_{}".format(now.strftime("%b").lower()),
                     default=now.strftime("%B"),
                 ),
                 target_language=date_lang,
@@ -965,15 +962,14 @@ class Status(SessionMixin, BrowserView, _StatusHelper):
             self.session_title = None
 
     def getStatus(self):
-        """Gather a list of the modules and locations in this survey as well
-        as data around their state of completion.
-        """
+        """Gather a list of the modules and locations in this survey as well as
+        data around their state of completion."""
         session = Session()
         total_ok = 0
         total_with_measures = 0
         modules = self.getModules()
         filtered_risks = self.getRisks([m["path"] for m in modules.values()])
-        for (module, risk) in filtered_risks:
+        for module, risk in filtered_risks:
             module_path = module.path
             has_measures = False
             if risk.identification in ["yes", "n/a"]:
@@ -1069,11 +1065,11 @@ class Status(SessionMixin, BrowserView, _StatusHelper):
         utils.setLanguage(self.request, self.survey, self.survey.language)
         self.update()
         self.getStatus()
-        return super(Status, self).__call__()
+        return super().__call__()
 
 
 class RisksOverview(Status):
-    """Implements the "Overview of Risks" report, see #10967"""
+    """Implements the "Overview of Risks" report, see #10967."""
 
     label = _("Overview of risks")
 
@@ -1083,13 +1079,13 @@ class RisksOverview(Status):
 
 
 class MeasuresOverview(Status):
-    """Implements the "Overview of Measures" report, see #10967"""
+    """Implements the "Overview of Measures" report, see #10967."""
 
     label = _("Overview of measures")
 
     def update(self):
         self.verify_view_permission()
-        super(MeasuresOverview, self).update()
+        super().update()
         lang = getattr(self.request, "LANGUAGE", "en")
         if "-" in lang:
             lang = lang.split("-")[0]
@@ -1103,7 +1099,7 @@ class MeasuresOverview(Status):
         self.monthstrings = [
             translate(
                 PloneLocalesMessageFactory(
-                    "month_{0}_abbr".format(month.lower()), default=month
+                    f"month_{month.lower()}_abbr", default=month
                 ),
                 target_language=lang,
             )
@@ -1192,3 +1188,27 @@ class MeasuresOverview(Status):
         self.modules = []
         for key in sorted(main_modules.keys()):
             self.modules.append(main_modules[key])
+
+
+class ExportJsonView(BrowserView):
+    @property
+    @memoize
+    def webhelpers(self):
+        return api.content.get_view("webhelpers", self.context, self.request)
+
+    def verify_view_permission(self):
+        if api.user.has_permission("Manage portal"):
+            return True
+        if not self.webhelpers.can_view_session:
+            raise Unauthorized
+
+    def get_payload(self):
+        """Serialize the session and its contents."""
+        session = self.context.session
+        return json.dumps(session, cls=SAJsonEncoder, indent=2, sort_keys=True)
+
+    def __call__(self):
+        self.verify_view_permission()
+        payload = self.get_payload()
+        self.request.response.setHeader("Content-Type", "application/json")
+        return payload
