@@ -1,4 +1,3 @@
-# coding=utf-8
 from euphorie.client import utils
 from euphorie.client.browser.country import SessionsView
 from euphorie.client.model import get_current_account
@@ -9,7 +8,7 @@ from zExceptions import Unauthorized
 
 
 class SurveySessionsView(SessionsView):
-    """Template corresponds to proto:_layout/tool.html"""
+    """Template corresponds to proto:_layout/tool.html."""
 
     variation_class = ""
 
@@ -19,7 +18,7 @@ class SurveySessionsView(SessionsView):
     @property
     @memoize
     def sessions(self):
-        """Given some sessions create a tree"""
+        """Given some sessions create a tree."""
         return self.webhelpers.get_sessions_query(context=self.context).all()
 
     def create_survey_session(self, title, account=None, **params):
@@ -35,7 +34,7 @@ class SurveySessionsView(SessionsView):
         session = Session()
         sector = self.context.aq_parent
         country = sector.aq_parent
-        zodb_path = "%s/%s/%s" % (country.id, sector.id, self.context.id)
+        zodb_path = f"{country.id}/{sector.id}/{self.context.id}"
         survey_session = self.survey_session_model(
             title=title,
             zodb_path=zodb_path,
@@ -63,8 +62,8 @@ class SurveySessionsViewAnon(SurveySessionsView):
 
 
 class DefaultIntroductionView(BrowserView):
-    """
-    Browser view that displays the default introduction text for a Suvey.
+    """Browser view that displays the default introduction text for a Suvey.
+
     It is used when the Survey does not define its own introduction
     """
 
