@@ -1,4 +1,3 @@
-# coding=utf-8
 from collections import OrderedDict
 from datetime import date
 from datetime import datetime
@@ -31,9 +30,8 @@ logger = getLogger(__name__)
 
 
 class TrainingSlide(BrowserView):
-    """Template / macro to hold the training slide markup
-    Currently not active in default Euphorie
-    """
+    """Template / macro to hold the training slide markup Currently not active
+    in default Euphorie."""
 
     @property
     @view_memoize
@@ -81,7 +79,7 @@ class TrainingSlide(BrowserView):
         else:
             number = self.context.number
         if self.item_type == "module":
-            number = "{}.0".format(number)
+            number = f"{number}.0"
         return number
 
     @property
@@ -135,14 +133,12 @@ class TrainingSlide(BrowserView):
             return training_notes
 
     @property
-    def measures(self):
+    def measures_in_place(self):
         if self.item_type != "risk":
             return {}
         measures = OrderedDict()
         for measure in list(self.context.in_place_standard_measures) + list(
             self.context.in_place_custom_measures
-            + list(self.context.standard_measures)
-            + list(self.context.custom_measures)
         ):
             if not measure.action:
                 continue
@@ -157,6 +153,33 @@ class TrainingSlide(BrowserView):
 
         return measures
 
+    @property
+    def measures_planned(self):
+        if self.item_type != "risk":
+            return {}
+        measures = OrderedDict()
+        for measure in list(self.context.standard_measures) + list(
+            self.context.custom_measures
+        ):
+            if not measure.action:
+                continue
+            measures.update(
+                {
+                    measure.id: {
+                        "action": self.webhelpers.get_safe_html(measure.action),
+                        "active": measure.used_in_training,
+                    }
+                }
+            )
+
+        return measures
+
+    @property
+    def measures(self):
+        measures = self.measures_in_place
+        measures.update(self.measures_planned)
+        return measures
+
     @property
     def image(self):
         if self.is_custom:
@@ -210,12 +233,13 @@ class TrainingSlide(BrowserView):
                 )
         return urls
 
-    def slide_contents(self, standalone=False):
-
+    def slide_contents(self):
         return {
             "slide_type": self.item_type,
             "slide_template": self.slide_template,
-            "measures": self.measures,
+            "measures_in_place": self.measures_in_place,
+            "measures_planned": self.measures_planned,
+            "measures": self.measures,  # BBB
             "training_notes": self.training_notes,
         }
 
@@ -253,13 +277,17 @@ class TrainingSlide(BrowserView):
 
 
 class TrainingView(BrowserView, survey._StatusHelper):
-    """The view that shows the main-menu Training module"""
+    """The view that shows the main-menu Training module."""
 
     variation_class = "variation-risk-assessment"
     skip_unanswered = False
     for_download = False
     more_menu_contents = []
-    heading_measures = _("header_measures", default="Measures")
+    heading_measures_in_place = _(
+        "label_existing_measures", default="Already implemented measures"
+    )
+    heading_measures_planned = _("label_planned_measures", default="Planned measures")
+    show_slide_byline = True
 
     @property
     @view_memoize
@@ -269,7 +297,7 @@ class TrainingView(BrowserView, survey._StatusHelper):
     @property
     @view_memoize
     def session(self):
-        """Return the session for this context/request"""
+        """Return the session for this context/request."""
         return self.context.session
 
     @property
@@ -278,9 +306,8 @@ class TrainingView(BrowserView, survey._StatusHelper):
         return self.session.modified.strftime("%s%M%H%d%m")
 
     def get_initial_answers(self):
-        """Pick a subset of questions, shuffle them, and initialize the answers with
-        None.
-        """
+        """Pick a subset of questions, shuffle them, and initialize the answers
+        with None."""
         survey = self.webhelpers._survey
         all_questions = survey.listFolderContents(
             {"portal_type": "euphorie.training_question"}
@@ -294,7 +321,7 @@ class TrainingView(BrowserView, survey._StatusHelper):
 
     @memoize
     def get_or_create_training(self):
-        """Return the training for this session"""
+        """Return the training for this session."""
         account_id = self.webhelpers.get_current_account().id
         session_id = self.webhelpers.session_id
         try:
@@ -336,7 +363,7 @@ class TrainingView(BrowserView, survey._StatusHelper):
             {"portal_type": "euphorie.training_question"}
         ) and self.training_status not in ("correct", "success"):
             view_name = "slide_question_intro"
-        return "{}/@@{}".format(self.context.absolute_url(), view_name)
+        return f"{self.context.absolute_url()}/@@{view_name}"
 
     @property
     @view_memoize
@@ -347,7 +374,7 @@ class TrainingView(BrowserView, survey._StatusHelper):
 
     @property
     def enable_training_questions(self):
-        """Explicit property that can be overwritten in subpackages"""
+        """Explicit property that can be overwritten in subpackages."""
         return bool(self.question_intro_url)
 
     def slicePath(self, path):
@@ -388,7 +415,7 @@ class TrainingView(BrowserView, survey._StatusHelper):
         risks = self.getRisks(modules, skip_unanswered=self.skip_unanswered)
         seen_modules = []
         data = OrderedDict()
-        for (module, risk) in risks:
+        for module, risk in risks:
             module_path = module.path
             if module_path not in seen_modules:
                 module_in_context = module.__of__(self.webhelpers.traversed_session)
@@ -425,8 +452,12 @@ class TrainingView(BrowserView, survey._StatusHelper):
         count = 0
         for data in self.slide_data.values():
             count += 1
-            for measure_id in data["slide_contents"]["measures"]:
-                if data["slide_contents"]["measures"][measure_id]["active"]:
+            for measure_id in data["slide_contents"]["measures_in_place"]:
+                if data["slide_contents"]["measures_in_place"][measure_id]["active"]:
+                    count += 1
+                    break
+            for measure_id in data["slide_contents"]["measures_planned"]:
+                if data["slide_contents"]["measures_planned"][measure_id]["active"]:
                     count += 1
                     break
             if (
@@ -517,12 +548,17 @@ class TrainingView(BrowserView, survey._StatusHelper):
             if "risk_id" in reply:
                 self.handle_measure_configuration(reply)
 
-        self.request.RESPONSE.addHeader("Cache-Control", "public,max-age=60")
+        # XXX This is commented because it causes problems on logout, see:
+        # - https://github.com/euphorie/Euphorie/issues/475
+        #
+        # We should come out with a better solution that does not require setting
+        # the cache headers here.
+        # self.request.RESPONSE.addHeader("Cache-Control", "public,max-age=60")
         return self.index()
 
 
 class SlideQuestionIntro(TrainingView):
-    """The slide that introduces the questions"""
+    """The slide that introduces the questions."""
 
     @property
     @view_memoize
@@ -534,7 +570,7 @@ class SlideQuestionIntro(TrainingView):
         return self.webhelpers._survey.title
 
     def first_question_url(self):
-        """Check the questions in the survey and take the first one"""
+        """Check the questions in the survey and take the first one."""
         if not self.question_ids:
             return ""
         return "{base_url}/@@slide_question/{slide_id}".format(
@@ -544,9 +580,8 @@ class SlideQuestionIntro(TrainingView):
 
 @implementer(IPublishTraverse)
 class SlideQuestion(SlideQuestionIntro):
-    """The view for a question slide, the question id has to be passed
-    as a traversal parameter
-    """
+    """The view for a question slide, the question id has to be passed as a
+    traversal parameter."""
 
     def publishTraverse(self, request, name):
         self.question_id = name
@@ -555,13 +590,13 @@ class SlideQuestion(SlideQuestionIntro):
     @property
     @view_memoize
     def question(self):
-        """The question we want to display"""
+        """The question we want to display."""
         return self.webhelpers._survey[self.question_id]
 
     @property
     @view_memoize
     def answers(self):
-        """Return the randomized answers for this question"""
+        """Return the randomized answers for this question."""
         question = self.question
         answers = [
             question.right_answer,
@@ -573,9 +608,9 @@ class SlideQuestion(SlideQuestionIntro):
 
     @property
     def progress(self):
-        """Return a progress indicator, something like 2/3"""
+        """Return a progress indicator, something like 2/3."""
         idx = self.question_ids.index(self.question_id)
-        return "{}/{}".format(idx + 1, len(self.question_ids))
+        return f"{idx + 1}/{len(self.question_ids)}"
 
     @property
     @view_memoize
@@ -599,20 +634,22 @@ class SlideQuestion(SlideQuestionIntro):
 
     @property
     def next_url(self):
-        """Go to next question (if we have one) or to the success or try again slides"""
+        """Go to next question (if we have one) or to the success or try again
+        slides."""
         next_question_id = self.next_question_id
         if next_question_id:
-            next_slide = "slide_question/{}".format(next_question_id)
+            next_slide = f"slide_question/{next_question_id}"
         elif self.get_or_create_training().status == "correct":
             next_slide = "slide_question_success"
         else:
             next_slide = "slide_question_try_again"
-        return "{}/@@{}".format(self.context.absolute_url(), next_slide)
+        return f"{self.context.absolute_url()}/@@{next_slide}"
 
     def initialize_training(self):
         """Initialize the training.
-        This is particularly important if the user starts again the training
-        after a first attempt
+
+        This is particularly important if the user starts again the
+        training after a first attempt
         """
         training = self.get_or_create_training()
         answer_history = loads(training.answers)
@@ -662,7 +699,7 @@ class SlideQuestion(SlideQuestionIntro):
         self.validate()
         if self.posted():
             return self.request.response.redirect(self.next_url)
-        return super(SlideQuestion, self).__call__()
+        return super().__call__()
 
 
 class SlideQuestionSuccess(SlideQuestionIntro):
@@ -677,7 +714,7 @@ class SlideQuestionSuccess(SlideQuestionIntro):
             raise Unauthorized("You do not own the certificate")
         if self.request.method == "POST":
             return self.post()
-        return super(SlideQuestionSuccess, self).__call__()
+        return super().__call__()
 
 
 class SlideQuestionTryAgain(SlideQuestionIntro):
@@ -698,12 +735,17 @@ class SlideQuestionTryAgain(SlideQuestionIntro):
 
 class MyTrainingsPortlet(BrowserView):
     columns = "1"
+    element_id = "portlet-training"
 
     @property
     @memoize
     def webhelpers(self):
         return api.content.get_view("webhelpers", self.context, self.request)
 
+    @property
+    def available(self):
+        return self.my_unfinished_trainings or self.my_certificates
+
     @property
     @memoize
     def my_unfinished_trainings(self):
