@@ -1,4 +1,3 @@
-# coding=utf-8
 from AccessControl import getSecurityManager
 from Acquisition import aq_base
 from Acquisition import aq_chain
@@ -14,17 +13,15 @@ from euphorie.client.client import IClient
 from euphorie.client.country import IClientCountry
 from euphorie.client.model import get_current_account
 from euphorie.client.model import Group
-from euphorie.client.model import Risk
+from euphorie.client.model import OrganisationMembership
 from euphorie.client.model import Session
 from euphorie.client.model import SurveySession
-from euphorie.client.model import SurveyTreeItem
 from euphorie.client.sector import IClientSector
 from euphorie.client.update import wasSurveyUpdated
 from euphorie.client.utils import getSecret
 from euphorie.content.survey import ISurvey
 from euphorie.content.utils import getRegionTitle
 from euphorie.content.utils import StripMarkup
-from euphorie.ghost import PathGhost
 from json import dumps
 from logging import getLogger
 from os import path
@@ -42,7 +39,8 @@ from Products.CMFCore.utils import getToolByName
 from Products.CMFPlone.interfaces import ISecuritySchema
 from Products.Five import BrowserView
 from Products.statusmessages.interfaces import IStatusMessage
-from six.moves.urllib.parse import urlencode
+from sqlalchemy import and_
+from urllib.parse import urlencode
 from user_agents import parse
 from ZODB.POSException import POSKeyError
 from zope.component import getMultiAdapter
@@ -104,10 +102,12 @@ class WebHelpers(BrowserView):
     favicon_path = "++resource++euphorie.resources/{brand}/favicon/apple-touch-icon.png"
 
     group_model = Group
+    hide_organisation_tab = False
     survey_session_model = SurveySession
+    dashboard_tabs = ["surveys", "assessments", "organisation"]
 
     def to_decimal(self, value):
-        """Transform value in to a decimal"""
+        """Transform value in to a decimal."""
         return Decimal(value)
 
     @property
@@ -204,11 +204,8 @@ class WebHelpers(BrowserView):
     def use_help_section(self):
         return api.portal.get_registry_record("euphorie.use_help_section", default=True)
 
-    @property
-    @memoize
-    def show_completion_percentage(self):
-        """Feature switch, can be overwritten in subclass"""
-        return False
+    # Feature switch, can be overwritten in subclass
+    show_completion_percentage = False
 
     @property
     @memoize
@@ -244,10 +241,12 @@ class WebHelpers(BrowserView):
                 return obj
 
     def redirectOnSurveyUpdate(self):
-        """Utility method for views to check if a survey has been updated,
-        and if so redirect the user to the update confirmation page is
-        generated. The return value is `True` if an update is required and
-        `False` otherwise."""
+        """Utility method for views to check if a survey has been updated, and
+        if so redirect the user to the update confirmation page is generated.
+
+        The return value is `True` if an update is required and `False`
+        otherwise.
+        """
         traversed_session = self.traversed_session
         session = traversed_session.session
         survey = traversed_session.aq_parent
@@ -266,49 +265,16 @@ class WebHelpers(BrowserView):
         traversed_session = self.traversed_session
         return traversed_session.session.id if traversed_session else ""
 
+    @memoize
+    @deprecate(
+        "Replace with session.completion_percentage "
+        "or self.traversed_session.session.completion_percentage. "
+        "Deprecated in version 14.1.4.dev0"
+    )
     def update_completion_percentage(self, session=None):
         if not session:
             session = self.traversed_session.session
-        query = (
-            Session.query(SurveyTreeItem)
-            .filter(SurveyTreeItem.session_id == session.id)
-            .filter(SurveyTreeItem.type == "module")
-            .filter(SurveyTreeItem.skip_children == False)  # noqa: E712
-        ).order_by(SurveyTreeItem.depth)
-        total_risks = 0
-        answered_risks = 0
-
-        @memoize
-        def recursive_skip_children(module):
-            return module.skip_children or (
-                module.parent and recursive_skip_children(module.parent)
-            )
-
-        for module in query:
-            if not module.path:
-                # XXX When does a module not have a path?
-                continue
-            if recursive_skip_children(module):
-                continue
-            total_risks_query = (
-                Session.query(Risk)
-                .filter(Risk.session_id == session.id)
-                .filter(Risk.path.like(module.path + "%"))
-                .filter(Risk.depth == module.depth + 1)
-            )
-            total_risks = total_risks + total_risks_query.count()
-            answered_risks_query = total_risks_query.filter(
-                Risk.identification != None  # noqa: E711
-            )
-            answered_risks = answered_risks + answered_risks_query.count()
-
-        completion_percentage = (
-            int(round((answered_risks * 1.0 / total_risks * 1.0) * 100.0))
-            if total_risks
-            else 0
-        )
-        session.completion_percentage = completion_percentage
-        return completion_percentage
+        return session.completion_percentage
 
     def get_progress_indicator_title(self, completion_percentage=None):
         if completion_percentage is None and self.traversed_session is not None:
@@ -374,8 +340,10 @@ class WebHelpers(BrowserView):
     @property
     @memoize
     def selected_country(self):
-        """Return the country id that is present in the path. Fall back to the
-        default_country"""
+        """Return the country id that is present in the path.
+
+        Fall back to the default_country
+        """
         country = self.county_obj_via_parents
         if country:
             return country.getId()
@@ -434,7 +402,7 @@ class WebHelpers(BrowserView):
     @property
     @forever.memoize
     def available_help_languages(self):
-        exclude = set(["illustrations"])
+        exclude = {"illustrations"}
         return set(resource_listdir("euphorie.client", "resources/oira/help")) - exclude
 
     @property
@@ -465,7 +433,8 @@ class WebHelpers(BrowserView):
     @property
     @memoize
     def country(self):
-        """XXX it would be better to write this country id, consider deprecating this"""
+        """XXX it would be better to write this country id, consider
+        deprecating this."""
         obj = self.country_obj
         if not obj:
             return ""
@@ -500,8 +469,10 @@ class WebHelpers(BrowserView):
     @property
     @memoize
     def sector_title(self):
-        """Return the title to use for the current sector. If the current
-        context is not in a sector return the agency name instead.
+        """Return the title to use for the current sector.
+
+        If the current context is not in a sector return the agency name
+        instead.
         """
         sector = self.sector
         if sector is not None and getattr(aq_base(sector), "logo", None) is not None:
@@ -535,15 +506,18 @@ class WebHelpers(BrowserView):
     @property
     @memoize
     def country_or_client_url(self):
-        """Return the country URL, but fall back to the client URL in case
-        the country URL is None.
-        Relevant in tests only, as far as I can see"""
+        """Return the country URL, but fall back to the client URL in case the
+        country URL is None.
+
+        Relevant in tests only, as far as I can see
+        """
         return self.country_url or self.client_url
 
     def _base_url(self):
         """Return a base URL to be used for non-survey specific pages.
-        If we are in a survey the help page will be located there. Otherwise
-        the country will be used as parent.
+
+        If we are in a survey the help page will be located there.
+        Otherwise the country will be used as parent.
         """
         base_url = self.survey_url()
         if base_url is not None and aq_inner(self.context).absolute_url().startswith(
@@ -568,17 +542,17 @@ class WebHelpers(BrowserView):
     @property
     @memoize
     def certificates_url(self):
-        return "{}/{}".format(self.client_url, self.certificates_path)
+        return f"{self.client_url}/{self.certificates_path}"
 
     @property
     @memoize
     def media_url(self):
-        return "{}/{}".format(self.client_url, self.media_path)
+        return f"{self.client_url}/{self.media_path}"
 
     @property
     @memoize
     def style_url(self):
-        return "{}/{}".format(self.client_url, self.style_path)
+        return f"{self.client_url}/{self.style_path}"
 
     @property
     @memoize
@@ -648,8 +622,8 @@ class WebHelpers(BrowserView):
         return ""
 
     def get_dashboard_tab(self):
-        head, tail = path.split(self.request.PATH_INFO)
-        if tail in ["surveys", "assessments"]:
+        tail = path.split(self.request.PATH_INFO.rstrip("/"))[-1].lstrip("@@")
+        if tail in self.dashboard_tabs:
             return tail
         return "dashboard"
 
@@ -668,17 +642,21 @@ class WebHelpers(BrowserView):
     @property
     @memoize
     def help_url(self):
-        """Return the URL to the current online help page. If we are in a
-        survey the help page will be located there. Otherwise the country
-        will be used as parent."""
+        """Return the URL to the current online help page.
+
+        If we are in a survey the help page will be located there.
+        Otherwise the country will be used as parent.
+        """
         return "%s/help" % self._base_url()
 
     @property
     @memoize
     def about_url(self):
-        """Return the URL to the current online about page. If we are in a
-        survey the help page will be located there. Otherwise the country
-        will be used as parent."""
+        """Return the URL to the current online about page.
+
+        If we are in a survey the help page will be located there.
+        Otherwise the country will be used as parent.
+        """
         return "%s/about" % self._base_url()
 
     @property
@@ -724,12 +702,20 @@ class WebHelpers(BrowserView):
             if ISurvey.providedBy(parent):
                 return parent
 
+    @property
+    @memoize
+    def is_survey(self):
+        """Return `True` if the webhelper's context is within a survey, `False`
+        otherwise.
+        """
+        return bool(self._survey)
+
     @memoize
     def survey_url(self, phase=None):
         """Return the URL for the curreny survey.
 
-        If a phase is specified the URL for the first page of that
-        phase is returned.
+        If a phase is specified the URL for the first page of that phase
+        is returned.
         """
         survey = self._survey
         if not survey:
@@ -742,8 +728,8 @@ class WebHelpers(BrowserView):
 
     @memoize
     def survey_zodb_path(self):
-        """
-        Construct zodb_path from current survey.
+        """Construct zodb_path from current survey.
+
         Helper method, since I don't always trust self.session.zodb_path
         """
         elems = []
@@ -772,9 +758,8 @@ class WebHelpers(BrowserView):
         return self._survey is not None
 
     def is_initialised_session(self, session):
-        """
-        A session without children has not passed the Identification phase yet
-        """
+        """A session without children has not passed the Identification phase
+        yet."""
         return session.children().count()
 
     @property
@@ -802,7 +787,7 @@ class WebHelpers(BrowserView):
 
         base_url = self._base_url()
         return [
-            {"url": "%s/appendix/%s" % (base_url, page.id), "title": page.Title()}
+            {"url": f"{base_url}/appendix/{page.id}", "title": page.Title()}
             for page in appendix.values()
         ]
 
@@ -810,8 +795,7 @@ class WebHelpers(BrowserView):
     @memoize
     def is_iphone(self):
         """Check if the current request is from an iPhone or similar device
-        (such as an iPod touch).
-        """
+        (such as an iPod touch)."""
         agent = self.request.get_header("User-Agent", "")
         return "iPhone" in agent
 
@@ -884,7 +868,7 @@ class WebHelpers(BrowserView):
             message = dict(
                 title=StripMarkup(motd.description),
                 text=motd.body,
-                id="motd{0}{1}".format(
+                id="motd{}{}".format(
                     motd.modification_date.strftime("%Y%m%d%H%M%S"),
                     now.strftime("%Y%m%d"),
                 ),
@@ -894,8 +878,6 @@ class WebHelpers(BrowserView):
     def tool_notification(self):
         message = None
         obj = self._survey
-        if isinstance(obj, PathGhost):
-            obj = self.context.aq_parent
         if ISurvey.providedBy(obj) and obj.hasNotification():
             now = datetime.now()
             message = dict(
@@ -938,7 +920,25 @@ class WebHelpers(BrowserView):
         if not account:
             return False
         session = self.traversed_session.session
-        return session in account.sessions or session in account.acquired_sessions
+
+        # Check if it is my session
+        if session.account_id == account.id:
+            return True
+
+        # Check if it is a session of my organisation
+        if (
+            Session()
+            .query(OrganisationMembership)
+            .filter(
+                and_(
+                    OrganisationMembership.owner_id == session.account_id,
+                    OrganisationMembership.member_id == account.id,
+                )
+            )
+            .count()
+        ):
+            return True
+        return session in account.acquired_sessions
 
     @property
     @memoize
@@ -967,7 +967,7 @@ class WebHelpers(BrowserView):
     @property
     @memoize
     def is_owner(self):
-        """Check if the current user is the owner of the session"""
+        """Check if the current user is the owner of the session."""
         session = self.traversed_session.session
         return self.get_current_account() == session.account
 
@@ -977,7 +977,7 @@ class WebHelpers(BrowserView):
         return self.use_clone_feature
 
     def resume(self, session):
-        """Resume a session for the current user if he is allowed to"""
+        """Resume a session for the current user if he is allowed to."""
         raise Exception("Obsolete, we traverse to sessions now")
 
     def as_md(self, text):
@@ -985,7 +985,7 @@ class WebHelpers(BrowserView):
         return "\r\n".join([x for x in text.split("\r")])
 
     def show_logo(self):
-        """In plain Euphorie, the logo is always shown"""
+        """In plain Euphorie, the logo is always shown."""
         return True
 
     @property
@@ -1004,19 +1004,17 @@ class WebHelpers(BrowserView):
     @property
     @memoize
     def custom_js(self):
-        """Return custom JavaScript where necessary"""
+        """Return custom JavaScript where necessary."""
         return ""
 
     @memoize_contextless
     def date_picker_i18n_json(self):
-        """Taken from:
-        https://github.com/ploneintranet/ploneintranet/blob/master/src/ploneintranet/layout/browser/date_picker.py  # noqa: E501
+        """Taken from: https://github.com/ploneintranet/ploneintranet/blob/mast
+        er/src/ploneintranet/layout/browser/date_picker.py  # noqa: E501.
 
-        Use this like:
-        <input class="pat-date-picker"
-               ...
-               data-pat-date-picker="...; i18n: ${portal_url}/@@date-picker-i18n.json; ..."
-               />
+        Use this like: <input class="pat-date-picker"        ... data-
+        pat-date-picker="...; i18n: ${portal_url}/@@date-
+        picker-i18n.json; ..."        />
         """
         json = dumps(
             {
@@ -1077,7 +1075,7 @@ class WebHelpers(BrowserView):
         filter_by_group=False,
         table=None,
     ):
-        """Method to return a query that looks for sessions
+        """Method to return a query that looks for sessions.
 
         :param context: limits the sessions under this context
         :param searchable_text: filters on survey title
@@ -1133,7 +1131,7 @@ class WebHelpers(BrowserView):
         lang = getattr(self.request, "LANGUAGE", "en")
         if "-" in lang:
             elems = lang.split("-")
-            lang = "{0}_{1}".format(elems[0], elems[1].upper())
+            lang = f"{elems[0]}_{elems[1].upper()}"
         messages = {
             "message-date": translate(
                 _("error_validation_date", default="This value must be a valid date"),
@@ -1162,12 +1160,156 @@ class WebHelpers(BrowserView):
                 target_language=lang,
             ),
         }
-        return "; ".join(
-            [
-                "{key}: {value}".format(key=key, value=value)
-                for key, value in messages.items()
-            ]
+        return "; ".join([f"{key}: {value}" for key, value in messages.items()])
+
+    @property
+    @memoize
+    def is_new_session(self):
+        if self.request.get("new_session"):
+            return True
+        session = self.traversed_session.session
+        return session.children().count() == 0
+
+    @property
+    @memoize
+    def survey_tree_data(self):
+        if self.anonymous:
+            return []
+
+        section = self.get_phase()
+        can_edit = self.can_edit_session
+        is_new_session = self.is_new_session
+        url = self.traversed_session.absolute_url()
+        integrated_action_plan = self.integrated_action_plan
+
+        data = []
+
+        active = section == "preparation"
+        disabled = section == ""
+        data.append(
+            {
+                "active": active,
+                "disabled": disabled,
+                "class": f'{"active" if active else ""}{"disabled" if disabled else ""}',  # noqa: E501
+                "id": "step-1",
+                "name": "preparation",
+                "href": f"{url}/@@start#content",
+                "title": api.portal.translate(
+                    _("label_preparation", default="Preparation")
+                ),
+                "has_tree": False,
+            }
         )
 
+        if self.use_involve_phase:
+            active = section == "involve"
+            disabled = section == "" or (section == "preparation" and is_new_session)
+            data.append(
+                {
+                    "active": active,
+                    "disabled": disabled,
+                    "class": f'{"active" if active else ""}{"disabled" if disabled else ""}',  # noqa: E501
+                    "id": "step-involve",
+                    "name": "involve",
+                    "href": f"{url}/@@involve#content",
+                    "title": api.portal.translate(
+                        _("label_involve", default="Involve")
+                    ),
+                    "has_tree": False,
+                }
+            )
+
+        active = section == "identification"
+        disabled = (section in ("", "preparation") and is_new_session) or not can_edit
+
+        title = ""
+        if integrated_action_plan:
+            title = api.portal.translate(_("label_assesment", "Assessment"))
+        else:
+            t1 = api.portal.translate(_("label_identification", "Identification"))
+            t2 = api.portal.translate(_("label_evaluation", "Evaluation"))
+            title = f"{t1} + {t2}"
+        data.append(
+            {
+                "active": active,
+                "disabled": disabled,
+                "class": f'{"active" if active else ""}{"disabled" if disabled else ""}',  # noqa: E501
+                "id": "step-2",
+                "name": "identification",
+                "href": f"{url}/@@identification#content",
+                "title": title,
+                "has_tree": active,
+            }
+        )
+
+        if not integrated_action_plan:
+            # The tree for the action section uses the same structure as the
+            # identification tree, with the only differences that only risks
+            # and their parent modules are shown and that the entire tree is
+            # expanded.
+            active = section == "actionplan"
+            data.append(
+                {
+                    "active": active,
+                    "disabled": disabled,
+                    "class": f'{"active" if active else ""}{"disabled" if disabled else ""}',  # noqa: E501
+                    "id": "step-4",
+                    "name": "action-plan",
+                    "href": f"{url}/@@actionplan#content",
+                    "title": api.portal.translate(
+                        _("label_action_plan", default="Action Plan")
+                    ),
+                    "has_tree": active,
+                }
+            )
+
+        # TODO: check if guest.
+        active = section == "report"
+        data.append(
+            {
+                "active": active,
+                "disabled": disabled,
+                "class": f'{"active" if active else ""}{"disabled" if disabled else ""}',  # noqa: E501
+                "id": "step-5",
+                "name": "report",
+                "href": f"{url}/@@report#content",
+                "title": api.portal.translate(_("label_report", default="Report")),
+                "has_tree": False,
+            }
+        )
+
+        if self.use_training_module:
+            active = section == "training"
+            data.append(
+                {
+                    "active": active,
+                    "disabled": disabled,
+                    "class": f'{"active" if active else ""}{"disabled" if disabled else ""}',  # noqa: E501
+                    "id": "step-6",
+                    "name": "training",
+                    "href": f"{url}/@@training#content",
+                    "title": api.portal.translate(
+                        _("menu_training", default="Training")
+                    ),
+                    "has_tree": False,
+                }
+            )
+
+        active = section == "status"
+        data.append(
+            {
+                "active": active,
+                "disabled": disabled,
+                "class": f'{"active" if active else ""}{"disabled" if disabled else ""}',  # noqa: E501
+                "id": "status",
+                "name": "status",
+                "href": f"{url}/@@status#content",
+                "title": api.portal.translate(_("navigation_status", default="Status")),
+                "has_tree": False,
+            }
+        )
+
+        return data
+
     def __call__(self):
         return self
