@@ -1,4 +1,3 @@
-# coding=utf-8
 from copy import deepcopy
 from datetime import date
 from docx.api import Document
@@ -61,12 +60,12 @@ def node_title(node, zodbnode):
     return node.title
 
 
-class BaseOfficeCompiler(object):
-
+class BaseOfficeCompiler:
     justifiable_map = {"yes": "Yes", "no": "No"}
 
     def xmlprint(self, obj):
         """Utility method that pretty prints the xml serialization of obj.
+
         Useful in tests and in depug
         """
         obj = getattr(obj, "_element", obj)
@@ -81,7 +80,7 @@ class BaseOfficeCompiler(object):
         lang = getattr(self.request, "LANGUAGE", "en")
         if "-" in lang:
             elems = lang.split("-")
-            lang = "{0}_{1}".format(elems[0], elems[1].upper())
+            lang = f"{elems[0]}_{elems[1].upper()}"
         return lang
 
     @property
@@ -166,13 +165,12 @@ class BaseOfficeCompiler(object):
 
 
 class DocxCompiler(BaseOfficeCompiler):
-
     _base_filename = "oira.docx"
 
     @property
     def _template_filename(self):
         return resource_filename(
-            "euphorie.client.docx", "templates/{0}".format(self._base_filename)
+            "euphorie.client.docx", f"templates/{self._base_filename}"
         )
 
     # In case of templates that contain additional content before the actual
@@ -182,12 +180,14 @@ class DocxCompiler(BaseOfficeCompiler):
     sections_offset = 0
 
     def __init__(self, context, request=None):
-        """Read the docx template and initialize some instance attributes
-        that will be used to compile the template
-        """
+        """Read the docx template and initialize some instance attributes that
+        will be used to compile the template."""
         self.context = context
         self.request = request
         self.template = Document(self._template_filename)
+
+        self.compiler = HtmlToWord()
+
         self.use_existing_measures = api.portal.get_registry_record(
             "euphorie.use_existing_measures", default=False
         )
@@ -196,7 +196,7 @@ class DocxCompiler(BaseOfficeCompiler):
         self.italy_special = self.webhelpers.country == "it"
 
     def set_session_title_row(self, data):
-        """This fills the workspace activity run with some text"""
+        """This fills the workspace activity run with some text."""
         request = self.request
         self.template.paragraphs[self.paragraphs_offset].text = data["heading"]
         txt = self.t(_("toc_header", default="Contents"))
@@ -242,7 +242,6 @@ class DocxCompiler(BaseOfficeCompiler):
             self.add_report_section(nodes, heading, **extra)
 
     def add_report_section(self, nodes, heading, **extra):
-
         doc = self.template
         doc.add_paragraph(heading, style="Heading 1")
 
@@ -263,7 +262,7 @@ class DocxCompiler(BaseOfficeCompiler):
                 number = ".".join(["Ω"] + num_elems[1:])
 
             doc.add_paragraph(
-                "%s %s" % (number, title), style="Heading %d" % (node.depth + 1)
+                f"{number} {title}", style="Heading %d" % (node.depth + 1)
             )
 
             if node.type != "risk":
@@ -341,14 +340,14 @@ class DocxCompiler(BaseOfficeCompiler):
                 else:
                     description = zodb_node.description
 
-                doc = HtmlToWord(_sanitize_html(description or ""), doc)
+                self.compiler(_sanitize_html(description or ""), doc)
 
             if node.comment and node.comment.strip():
                 msg = translate(
                     _("heading_comments", default="Comments"), target_language=self.lang
                 )
                 doc.add_paragraph(msg, style="Measure Heading")
-                doc = HtmlToWord(_sanitize_html(node.comment or ""), doc)
+                self.compiler(_sanitize_html(node.comment or ""), doc)
 
             if not extra.get("skip_legal_references", True):
                 legal_reference = getattr(zodb_node, "legal_reference", None)
@@ -362,7 +361,7 @@ class DocxCompiler(BaseOfficeCompiler):
                         target_language=self.lang,
                     )
                     doc.add_paragraph(legal_heading, style="Legal Heading")
-                    doc = HtmlToWord(_sanitize_html(legal_reference), doc)
+                    self.compiler(_sanitize_html(legal_reference), doc)
 
             if not extra.get("use_solutions", False):
                 skip_planned_measures = extra.get("skip_planned_measures", False)
@@ -382,7 +381,7 @@ class DocxCompiler(BaseOfficeCompiler):
             if self.italy_special:
                 skip_planned_measures = True
 
-            for (idx, action_plan) in enumerate(
+            for idx, action_plan in enumerate(
                 node.in_place_standard_measures + node.in_place_custom_measures
             ):
                 heading = (
@@ -399,7 +398,7 @@ class DocxCompiler(BaseOfficeCompiler):
 
         if not skip_planned_measures:
             action_plans = node.standard_measures + node.custom_measures
-            for (idx, measure) in enumerate(action_plans):
+            for idx, measure in enumerate(action_plans):
                 if not measure.action:
                     continue
 
@@ -459,7 +458,7 @@ class DocxCompiler(BaseOfficeCompiler):
             ]
         for heading, value in zip(headings, values):
             doc.add_paragraph(heading, style="MeasureField")
-            doc = HtmlToWord(value, doc, style="MeasureText")
+            self.compiler(value, doc, style="MeasureText")
 
     def set_consultation_box(self):
         doc = self.template
@@ -495,7 +494,7 @@ class DocxCompiler(BaseOfficeCompiler):
         workers = self.t(
             _("oira_consultation_workers", default="On behalf of the workers:")
         )
-        paragraph.text = "{0}\t\t\t{1}".format(employer, workers)
+        paragraph.text = f"{employer}\t\t\t{workers}"
         cell.add_paragraph()
         cell.add_paragraph()
 
@@ -512,7 +511,6 @@ class DocxCompiler(BaseOfficeCompiler):
 
 
 class DocxCompilerItalyOriginal(DocxCompiler):
-
     _base_filename = "oira_it.docx"
 
     paragraphs_offset = 29
@@ -540,7 +538,7 @@ class DocxCompilerFullTable(DocxCompiler):
     title_extra = ""
 
     def __init__(self, context, request=None):
-        super(DocxCompilerFullTable, self).__init__(context, request)
+        super().__init__(context, request)
 
     def remove_row(self, row):
         tbl = row._parent._parent
@@ -549,9 +547,8 @@ class DocxCompilerFullTable(DocxCompiler):
 
     @memoize
     def get_modules_table(self):
-        """Returns the first table of the template,
-        which contains the modules
-        """
+        """Returns the first table of the template, which contains the
+        modules."""
         return self.template.tables[-1]
 
     @property
@@ -574,14 +571,13 @@ class DocxCompilerFullTable(DocxCompiler):
         return lookup
 
     def set_session_title_row(self, data):
-        """This fills the workspace activity run with some text
+        """This fills the workspace activity run with some text.
 
-        The run is empirically determined by studying the template.
-        This is in a paragraph structure before the first table.
-        Tou may want to change this if you change the template.
-        Be aware that the paragraph is the 2nd only
-        after this class is initialized.
-        We have 2 fields to fill, all following the same principle
+        The run is empirically determined by studying the template. This
+        is in a paragraph structure before the first table. Tou may want
+        to change this if you change the template. Be aware that the
+        paragraph is the 2nd only after this class is initialized. We
+        have 2 fields to fill, all following the same principle
         """
 
         data["today"] = formatDate(self.request, date.today())
@@ -628,6 +624,7 @@ class DocxCompilerFullTable(DocxCompiler):
 
     def set_cell_risk(self, cell, risk):
         """Take the risk and add the appropriate text:
+
         title, descripton, comment, measures in place
         """
         paragraph = cell.paragraphs[0]
@@ -654,9 +651,9 @@ class DocxCompilerFullTable(DocxCompiler):
                 paragraph.runs[0].italic = True
 
         if risk["comment"] and risk["comment"].strip():
-            HtmlToWord(risk["comment"], cell, style="Risk Normal")
+            self.compiler(risk["comment"], cell, style="Risk Normal")
         if self.show_risk_descriptions:
-            HtmlToWord(risk["description"], cell)
+            self.compiler(risk["description"], cell)
         if risk["measures"]:
             if self.show_risk_descriptions:
                 cell.add_paragraph()
@@ -671,19 +668,19 @@ class DocxCompilerFullTable(DocxCompiler):
                     style="Risk Italics",
                 )
             for measure in risk["measures"]:
-                HtmlToWord(_simple_breaks(measure), cell, style="Risk Italics List")
+                self.compiler(_simple_breaks(measure), cell, style="Risk Italics List")
         paragraph = cell.add_paragraph(style="Risk Normal")
 
     def set_cell_actions(self, cell, risk):
         """Take the risk and add the appropriate text:
+
         planned measures
         """
         paragraph = cell.paragraphs[0]
         for idx, action in enumerate(risk["actions"]):
             if idx != 0:
                 paragraph = cell.add_paragraph()
-            paragraph.style = "Measure List"
-            paragraph.text = _simple_breaks(action["text"])
+            self.compiler(_simple_breaks(action["text"]), cell, style="Measure List")
             if action.get("requirements", None):
                 paragraph = cell.add_paragraph(style="Measure Indent")
                 run = paragraph.add_run()
@@ -723,8 +720,9 @@ class DocxCompilerFullTable(DocxCompiler):
                 paragraph.runs[0].italic = True
 
     def merge_module_rows(self, row_module, row_risk):
-        """This merges the the first cell of the given rows,
-        the one containing the module title.
+        """This merges the the first cell of the given rows, the one containing
+        the module title.
+
         Also remove the horizontal borders between the not merged cells.
         """
         for idx in range(1):
@@ -736,7 +734,7 @@ class DocxCompilerFullTable(DocxCompiler):
             self.set_cell_border(cell, settings=LEFT_RIGHT_BORDERS)
 
     def set_modules_rows(self, data):
-        """This takes a list of modules and creates the rows for them"""
+        """This takes a list of modules and creates the rows for them."""
         modules = data.get("modules", [])
         table = self.get_modules_table()
 
@@ -787,9 +785,7 @@ class DocxCompilerFullTable(DocxCompiler):
                 self.set_row_borders(row_risk, settings=settings)
 
         def _merge_cells(cells):
-            """
-            Merge all given cells into one
-            """
+            """Merge all given cells into one."""
             if len(cells) < 2:
                 return cells
             cell1, rest = cells[0], cells[1:]
@@ -811,7 +807,7 @@ class DocxCompilerFullTable(DocxCompiler):
         pass
 
     def compile(self, data):
-        """Compile the template using data
+        """Compile the template using data.
 
         We need to compile two areas of the template:
 
@@ -903,7 +899,6 @@ class DocxCompilerItaly(DocxCompilerFullTable):
 
 class IdentificationReportCompiler(DocxCompiler):
     def set_session_title_row(self, data):
-
         request = self.request
         survey = self.context.aq_parent
 
