@@ -1,4 +1,3 @@
-# coding=utf-8
 from lxml import etree
 
 import docx
@@ -6,9 +5,15 @@ import htmllaundry
 import lxml.html
 
 
+# tag to style mapping which will be used over styles from the source document.
+ENFORCE_STYLES = {
+    "ul": "List Bullet",
+    "ol": "List Number",
+}
+
+
 def add_hyperlink(paragraph, url, text, style):
-    """
-    A function that places a hyperlink within a paragraph object.
+    """A function that places a hyperlink within a paragraph object.
 
     :param paragraph: The paragraph we are adding the hyperlink to.
     :param url: A string containing the required url
@@ -46,7 +51,7 @@ def add_hyperlink(paragraph, url, text, style):
     return hyperlink
 
 
-class _HtmlToWord(object):
+class HtmlToWord:
     def handleInlineText(self, node, p):
         """Handler for elements which can only contain inline text (p, li)"""
         run = p.add_run()
@@ -77,18 +82,27 @@ class _HtmlToWord(object):
         return p
 
     def handleElement(self, node, doc, style=None):
-        if node.tag in ["p", "li", "strong", "b", "em", "i", "u", "a"]:
+        style = ENFORCE_STYLES.get(node.tag) or style
+
+        if node.tag in [
+            "a",
+            "b",
+            "blockquote",
+            "em",
+            "h4",
+            "i",
+            "li",
+            "p",
+            "strong",
+            "u",
+        ]:
             p = doc.add_paragraph(style=style)
             p = self.handleInlineText(node, p)
         elif node.tag in ["ul", "ol"]:
-
-            if node.tag == "ul":
-                style = "List Bullet"
-            else:
-                style = "List Number"
             for sub in node:
                 if sub.tag == "li":
                     p = doc.add_paragraph(style=style)
+                    p.paragraph_format.left_indent = docx.shared.Inches(1)
                     p = self.handleInlineText(sub, p)
 
         tail = node.tail
@@ -96,11 +110,11 @@ class _HtmlToWord(object):
         # from newlines in the markup
         # if node.tag in ['li', 'p', 'strong', 'em', 'b', 'i']:
         tail = tail and tail.strip()
-        if tail:
+        if tail and not doc.text.endswith(tail):
             doc.add_paragraph(tail)
         return doc
 
-    def __call__(self, markup, doc, style=None):
+    def __call__(self, markup, doc, style=None, next_style=None):
         if not markup or not markup.strip():
             return doc
         try:
@@ -111,10 +125,11 @@ class _HtmlToWord(object):
             doc.add_paragraph(text)
             return doc
 
-        for node in markup_doc.find("body"):
-            doc = self.handleElement(node, doc, style)
+        for idx, node in enumerate(markup_doc.find("body")):
+            if idx == 0:
+                p_style = style
+            else:
+                p_style = next_style or style
+            doc = self.handleElement(node, doc, p_style)
 
         return doc
-
-
-HtmlToWord = _HtmlToWord()
