@@ -1,4 +1,3 @@
-# coding=utf-8
 """
 Model
 -----
@@ -7,13 +6,14 @@ Mainly: the connection between the ZODB-based content of the backend and the
 SQL-based individual session content of the client users.
 Also: PAS-based user account for users of the client
 """
-from __future__ import division
 from AccessControl.interfaces import IUser
 from AccessControl.PermissionRole import _what_not_even_god_should_do
 from AccessControl.SecurityInfo import ClassSecurityInfo
+from Acquisition import aq_chain
 from Acquisition import aq_inner
 from Acquisition import aq_parent
 from collections import defaultdict
+from euphorie.client.client import IClient
 from euphorie.client.enum import Enum
 from OFS.interfaces import IApplication
 from plone import api
@@ -46,7 +46,6 @@ import logging
 import OFS.Traversable
 import random
 import re
-import six
 
 
 BCRYPTED_PATTERN = re.compile(r"^\$2[aby]?\$\d{1,2}\$[.\/A-Za-z0-9]{53}$")
@@ -72,9 +71,9 @@ def GenerateSecret(length=32):
 class BaseObject(OFS.Traversable.Traversable, Acquisition.Implicit):
     """Zope 2-style base class for our models.
 
-    This base class allows SQL based objects to act like normal Zope 2 objects.
-    In particular it allows acquisition to find skin objects and keeps
-    absolute_url() and getPhysicalPath() working.
+    This base class allows SQL based objects to act like normal Zope 2
+    objects. In particular it allows acquisition to find skin objects
+    and keeps absolute_url() and getPhysicalPath() working.
     """
 
     __init__ = declarative.api._declarative_constructor
@@ -118,10 +117,10 @@ class BaseObject(OFS.Traversable.Traversable, Acquisition.Implicit):
 class SurveyTreeItem(BaseObject):
     """A tree of questions.
 
-    The data is stored in the form of a materialized tree. The path is built
-    using a list of item numbers. Each item number has three digits and uses
-    0-prefixing to make sure we can use simple string sorting to produce a
-    sorted tree.
+    The data is stored in the form of a materialized tree. The path is
+    built using a list of item numbers. Each item number has three
+    digits and uses 0-prefixing to make sure we can use simple string
+    sorting to produce a sorted tree.
     """
 
     __tablename__ = "tree"
@@ -341,20 +340,19 @@ class Group(BaseObject):
 
     @property
     def fullname(self):
-        """This is the name that will be display in the selectors and
-        in the tree widget
-        """
+        """This is the name that will be display in the selectors and in the
+        tree widget."""
         title = "{obs}{name}".format(
             obs="[obs.] " if not self.deactivated else "",
             name=self.short_name or self.group_id,
         )
         if self.responsible_fullname:
-            title += ", {}".format(self.responsible_fullname)
+            title += f", {self.responsible_fullname}"
         return title
 
     @property
     def descendantids(self):
-        """Return all the groups in the hierarchy flattened"""
+        """Return all the groups in the hierarchy flattened."""
         structure = self._group_structure
         ids = []
 
@@ -370,7 +368,7 @@ class Group(BaseObject):
 
     @property
     def descendants(self):
-        """Return all the groups in the hierarchy flattened"""
+        """Return all the groups in the hierarchy flattened."""
         return list(
             Session.query(self.__class__).filter(
                 self.__class__.group_id.in_(self.descendantids)
@@ -379,7 +377,7 @@ class Group(BaseObject):
 
     @property
     def parents(self):
-        """Return all the groups in the hierarchy flattened"""
+        """Return all the groups in the hierarchy flattened."""
         group = self
         parents = []
         while True:
@@ -392,9 +390,8 @@ class Group(BaseObject):
     @property
     @memoize
     def _group_structure(self):
-        """Return a dict like structure
-        with the group ids as keys and the children group ids as values
-        """
+        """Return a dict like structure with the group ids as keys and the
+        children group ids as values."""
         tree = defaultdict(set)
         for groupid, parentid in Session.query(Group.group_id, Group.parent_id).filter(
             Group.parent_id != None  # noqa: E711
@@ -404,7 +401,7 @@ class Group(BaseObject):
 
     @property
     def acquired_sessions(self):
-        """All the session relative to this group and its children"""
+        """All the session relative to this group and its children."""
         group_ids = [self.group_id]
         group_ids.extend(g.group_id for g in self.descendants)
         return (
@@ -415,7 +412,7 @@ class Group(BaseObject):
 
     @property
     def sessions(self):
-        """All the session relative to this group"""
+        """All the session relative to this group."""
         group_ids = [self.group_id]
         return (
             Session.query(SurveySession)
@@ -426,8 +423,10 @@ class Group(BaseObject):
 
 @implementer(IUser)
 class Account(BaseObject):
-    """A user account. Users have to register with euphorie before they can
-    start a survey session. A single account can have multiple survey sessions.
+    """A user account.
+
+    Users have to register with euphorie before they can start a survey
+    session. A single account can have multiple survey sessions.
     """
 
     __tablename__ = "account"
@@ -467,6 +466,17 @@ class Account(BaseObject):
         default=None,
     )
 
+    first_name = schema.Column(
+        types.Unicode(),
+        nullable=True,
+        default=None,
+    )
+    last_name = schema.Column(
+        types.Unicode(),
+        nullable=True,
+        default=None,
+    )
+
     @property
     def groups(self):
         group = self.group
@@ -500,14 +510,28 @@ class Account(BaseObject):
     @property
     def login(self):
         """This synchs naming with :obj:`euphorie.content.user.IUser` and is
-        needed by the authentication tools.
-        """
+        needed by the authentication tools."""
         return self.loginname
 
+    @property
+    def title(self):
+        """Return the joined first_name and last_name of the account if
+        present.
+
+        If they are not fallback to the loginname
+        """
+        return (
+            " ".join((self.first_name or "", self.last_name or "")).strip()
+            or self.loginname
+        )
+
     def getUserName(self):
         """Return the login name."""
         return self.loginname
 
+    def getGroups(self):
+        return ["AuthenticatedUsers"]
+
     def getRoles(self):
         """Return all global roles for this user."""
 
@@ -535,7 +559,7 @@ class Account(BaseObject):
         """Check if the user has a permission in a context."""
         return perm == "Euphorie: View a Survey"
 
-    def allowed(self, object, object_roles=None):
+    def allowed(self, context, object_roles=None):
         """Check if this account has any of the requested roles in the context
         of `object`."""
         if object_roles is _what_not_even_god_should_do:
@@ -544,20 +568,20 @@ class Account(BaseObject):
         if object_roles is None:
             return True
 
-        for role in ["Anonymous", "Authenticated", "EuphorieUser"]:
-            if role in object_roles:
-                return True
+        for obj in aq_chain(aq_inner(context)):
+            if IClient.providedBy(obj):
+                allowed_roles = {"Anonymous", "Authenticated", "EuphorieUser", "Reader"}
+                return bool(allowed_roles & set(object_roles))
 
         return False
 
     @ram.cache(_forever_cache_key)
     def verify_password(self, password):
-        """Verify the given password against the one
-        stored in the account table
-        """
+        """Verify the given password against the one stored in the account
+        table."""
         if not password:
             return False
-        if not isinstance(password, six.string_types):
+        if not isinstance(password, str):
             return False
         if password == self.password:
             return True
@@ -565,7 +589,7 @@ class Account(BaseObject):
         return bcrypt.checkpw(password, self.password)
 
     def hash_password(self):
-        """hash the account password using bcrypt"""
+        """Hash the account password using bcrypt."""
         try:
             password = self.password
         except AttributeError:
@@ -624,7 +648,7 @@ class AccountChangeRequest(BaseObject):
 
 
 class ISurveySession(Interface):
-    """Marker interface for a SurveySession object"""
+    """Marker interface for a SurveySession object."""
 
 
 @implementer(ISurveySession)
@@ -686,12 +710,6 @@ class SurveySession(BaseObject):
         default=None,
     )
 
-    completion_percentage = schema.Column(
-        types.Integer,
-        nullable=True,
-        default=0,
-    )
-
     zodb_path = schema.Column(types.String(512), nullable=False)
 
     report_comment = schema.Column(types.UnicodeText())
@@ -744,6 +762,7 @@ class SurveySession(BaseObject):
     @property
     def review_state(self):
         """Check if it the published column.
+
         If it has return 'published' otherwise return 'private'
         """
         return "published" if self.published else "private"
@@ -764,11 +783,13 @@ class SurveySession(BaseObject):
     def refresh_survey(self, survey=None):
         """Mark the session with the current date to indicate that is has been
         refreshed with the latest version of the Survey (from Zope).
-        If survey is passed, update all titles in the tree, based on the CMS
-        version of the survey, i.e. update all titles of modules and risks.
-        Those are used in the navigation. If a title change is the only change
-        in the CMS, the survey session is not re-created. Therefore this
-        method ensures that the titles are updated where necessary.
+
+        If survey is passed, update all titles in the tree, based on the
+        CMS version of the survey, i.e. update all titles of modules and
+        risks. Those are used in the navigation. If a title change is
+        the only change in the CMS, the survey session is not re-
+        created. Therefore this method ensures that the titles are
+        updated where necessary.
         """
         if survey:
             query = Session.query(SurveyTreeItem).filter(
@@ -783,6 +804,29 @@ class SurveySession(BaseObject):
                     item.title = zodb_item.title
         self.refreshed = datetime.datetime.now()
 
+    def update_measure_types(self, survey):
+        """Update measure types in the session according to changes in the
+        tool.
+
+        Specifically, if an `in_place_standard` measure is deleted in
+        the tool, it disappears from the identification phase of the
+        session unless we change its type to `in_place_custom`.
+        """
+        in_place_standard_measures = (
+            Session.query(Risk, ActionPlan)
+            .filter(Risk.id == ActionPlan.risk_id)
+            .filter(Risk.session_id == self.id)
+            .filter(ActionPlan.plan_type == "in_place_standard")
+            .all()
+        )
+        for risk, measure in in_place_standard_measures:
+            risk_zodb = survey.restrictedTraverse(risk.zodb_path.split("/"))
+            solution_ids_zodb = [sol.id for sol in risk_zodb._solutions]
+            if measure.solution_id not in solution_ids_zodb:
+                # The measure is in the session but not in the tool. It has probably
+                # been deleted. Keep it visible by making it a custom measure.
+                measure.plan_type = "in_place_custom"
+
     def addChild(self, item):
         sqlsession = Session()
         query = (
@@ -954,7 +998,7 @@ class SurveySession(BaseObject):
 
     @classmethod
     def get_account_filter(cls, account=None):
-        """Filter only the sessions for the given account
+        """Filter only the sessions for the given account.
 
         :param acount: True means current account.
             A falsish value means do not filter.
@@ -963,7 +1007,10 @@ class SurveySession(BaseObject):
             an object account will be used to extract the account id,
             from an iterable we will try to extract the account ids
         """
+        # TODO: this is too complex
+        include_organisation_members = False
         if account is True:
+            include_organisation_members = True
             account = get_current_account()
 
         if isinstance(account, Account):
@@ -972,20 +1019,29 @@ class SurveySession(BaseObject):
         if not account:
             return False
 
-        if isinstance(account, (int, six.string_types)):
+        if not include_organisation_members and isinstance(account, (int, (str,))):
             return cls.account_id == account
 
-        try:
-            account_ids = {getattr(item, "id", item) for item in account}
-        except TypeError:
-            log.error("Cannot understand the account parameter: %r", account)
-            raise
+        if include_organisation_members:
+            account_ids = {account}
+            # Add the owner id of the organisations where the account is member of
+            account_ids.update(
+                Session.query(OrganisationMembership.owner_id).filter(
+                    OrganisationMembership.member_id == account
+                )
+            )
+        else:
+            try:
+                # This works when we pass an iterable of accounts or ids
+                account_ids = {getattr(item, "id", item) for item in account}
+            except TypeError:
+                # this happens when account is not an iterable
+                log.error("Cannot understand the account parameter: %r", account)
+                raise
+            account_ids = {
+                item for item in account_ids if item and isinstance(item, (int, (str,)))
+            }
 
-        account_ids = {
-            item
-            for item in account_ids
-            if item and isinstance(item, (int, six.string_types))
-        }
         if not account_ids:
             return False
 
@@ -997,7 +1053,7 @@ class SurveySession(BaseObject):
 
     @classmethod
     def get_group_filter(cls, group=None):
-        """Filter only the sessions for the given group
+        """Filter only the sessions for the given group.
 
         :param group: True means the current account's group.
             A falsish value means do not filter.
@@ -1015,7 +1071,7 @@ class SurveySession(BaseObject):
         if not group:
             return False
 
-        if isinstance(group, (int, six.string_types)):
+        if isinstance(group, (int, (str,))):
             return cls.group_id == group
 
         try:
@@ -1025,9 +1081,7 @@ class SurveySession(BaseObject):
             raise
 
         group_ids = {
-            item
-            for item in group_ids
-            if item and isinstance(item, (int, six.string_types))
+            item for item in group_ids if item and isinstance(item, (int, (str,)))
         }
         if not group_ids:
             return False
@@ -1040,14 +1094,14 @@ class SurveySession(BaseObject):
 
     @classmethod
     def get_archived_filter(cls):
-        """Filter sessions that are archived"""
+        """Filter sessions that are archived."""
         return sql.or_(
             cls.archived >= localized_now(), cls.archived == None  # noqa: E711
         )
 
     @classmethod
     def _get_context_tools(cls, context):
-        """Return the set of tools we can find under this context"""
+        """Return the set of tools we can find under this context."""
         if not context:
             return set()
 
@@ -1080,7 +1134,7 @@ class SurveySession(BaseObject):
 
     @classmethod
     def get_context_filter(cls, context):
-        """Filter sessions under this context using the zodb_path column"""
+        """Filter sessions under this context using the zodb_path column."""
         surveys = cls._get_context_tools(context)
         if not surveys:
             return False
@@ -1101,10 +1155,56 @@ class SurveySession(BaseObject):
     def traversed_session(self):
         return self.tool.restrictedTraverse("++session++%s" % self.id)
 
+    def absolute_url(self):
+        """The URL for this session is based on the tool's URL.
+
+        To it (if it can be fetched) we add a traverser with the session
+        id.
+        """
+        client = api.portal.get().client
+        tool = client.unrestrictedTraverse(self.zodb_path, None)
+        if tool is None:
+            raise ValueError("No tool found for session %s" % self.id)
+        return f"{tool.absolute_url()}/++session++{self.id}"
+
     @property
     def country(self):
         return str(self.zodb_path).split("/")[0]
 
+    @property
+    def completion_percentage(self):
+        module_query = (
+            Session.query(SurveyTreeItem)
+            .filter(SurveyTreeItem.session_id == self.id)
+            .filter(SurveyTreeItem.type == "module")
+        ).order_by(SurveyTreeItem.path)
+
+        good_module_ids = set()
+        bad_module_ids = set()
+        for module in module_query:
+            if module.parent_id in bad_module_ids or module.skip_children:
+                bad_module_ids.add(module.id)
+            else:
+                good_module_ids.add(module.id)
+
+        if not good_module_ids:
+            return 0
+
+        total_risks_query = Session.query(Risk).filter(
+            Risk.parent_id.in_(good_module_ids)
+        )
+        total = total_risks_query.count()
+
+        if not total:
+            return 0
+
+        answered = float(
+            total_risks_query.filter(Risk.identification != None).count()  # noqa: E711
+        )
+
+        completion_percentage = int(round(answered / total * 100.0))
+        return completion_percentage
+
 
 class Company(BaseObject):
     """Information about a company."""
@@ -1283,7 +1383,7 @@ class ActionPlan(BaseObject):
 
 
 class Training(BaseObject):
-    """Data table to record trainings"""
+    """Data table to record trainings."""
 
     __tablename__ = "training"
 
@@ -1313,6 +1413,63 @@ class Training(BaseObject):
     status = schema.Column(types.Unicode)
 
 
+class Organisation(BaseObject):
+    """A table to store some data about an organisation."""
+
+    __tablename__ = "organisation"
+
+    organisation_id = schema.Column(
+        types.Integer(),
+        primary_key=True,
+        autoincrement=True,
+    )
+    owner_id = schema.Column(
+        types.Integer(),
+        schema.ForeignKey(Account.id, onupdate="CASCADE", ondelete="CASCADE"),
+        nullable=False,
+    )
+    title = schema.Column(types.UnicodeText())
+    image_data = schema.Column(types.LargeBinary())
+    image_data_scaled = schema.Column(types.LargeBinary())
+    image_filename = schema.Column(types.UnicodeText())
+    owner = orm.relation(
+        Account,
+        backref=orm.backref(
+            "organisation",
+            uselist=False,
+            cascade="all, delete, delete-orphan",
+            foreign_keys=[owner_id],
+        ),
+    )
+
+
+class OrganisationMembership(BaseObject):
+    """This table wants to mimic the concept of an organisation for Euphorie.
+
+    The goal is to share permissions to work on sessions from another
+    user.
+    """
+
+    __tablename__ = "organisation_membership"
+
+    organisation_id = schema.Column(
+        types.Integer(),
+        primary_key=True,
+        autoincrement=True,
+    )
+    owner_id = schema.Column(
+        types.Integer(),
+        schema.ForeignKey(Account.id, onupdate="CASCADE", ondelete="CASCADE"),
+        nullable=False,
+    )
+    member_id = schema.Column(
+        types.Integer(),
+        schema.ForeignKey(Account.id, onupdate="CASCADE", ondelete="CASCADE"),
+        nullable=False,
+    )
+    member_role = schema.Column(types.UnicodeText())
+
+
 _instrumented = False
 if not _instrumented:
     metadata._decl_registry = {}
@@ -1327,6 +1484,8 @@ if not _instrumented:
         AccountChangeRequest,
         Company,
         Training,
+        Organisation,
+        OrganisationMembership,
     ]:
         declarative.api.instrument_declarative(cls, metadata._decl_registry, metadata)
     _instrumented = True
@@ -1422,7 +1581,7 @@ MODULE_WITH_RISK_TOP5_TNO_FILTER = sql.and_(
                         Risk.risk_type == "top5",
                         sql.or_(
                             sql.not_(Risk.identification.in_(["n/a", "yes"])),
-                            Risk.identification == None,  # noqa: E712
+                            Risk.identification is None,
                         ),
                     ),
                 ),
@@ -1443,7 +1602,7 @@ MODULE_WITH_RISK_NO_TOP5_NO_POLICY_DO_EVALUTE_FILTER = sql.and_(
                 child_node.id == Risk.sql_risk_id,
                 child_node.type == "risk",
                 sql.not_(Risk.risk_type.in_(["top5", "policy"])),
-                sql.not_(Risk.skip_evaluation == True),
+                sql.not_(Risk.skip_evaluation is True),
                 Risk.identification == "no",
                 child_node.depth > SurveyTreeItem.depth,
                 child_node.path.like(SurveyTreeItem.path + "%"),
@@ -1547,7 +1706,7 @@ MODULE_WITH_UNANSWERED_RISKS_FILTER = sql.and_(
                 child_node.session_id == SurveyTreeItem.session_id,
                 child_node.id == Risk.sql_risk_id,
                 child_node.type == "risk",
-                Risk.identification == None,
+                Risk.identification is None,
                 child_node.depth > SurveyTreeItem.depth,
                 child_node.path.like(SurveyTreeItem.path + "%"),
             )
@@ -1587,8 +1746,8 @@ del child_node
 
 
 def get_current_account():
-    """XXX this would be better placed in an api module,
-    but we need to avoid circular dependencies
+    """XXX this would be better placed in an api module, but we need to avoid
+    circular dependencies.
 
     :return: The current Account instance if a user can be found,
              otherwise None
@@ -1602,12 +1761,13 @@ def get_current_account():
 
 
 class DefaultView(BrowserView):
-    """Default @@index_html view for the objects in the model"""
+    """Default @@index_html view for the objects in the model."""
 
     def __call__(self):
         """Somebody called the default view for this object:
-        we do not want this to happen so we display a message and redirect the user
-        to the session start page
+
+        we do not want this to happen so we display a message and
+        redirect the user to the session start page
         """
         api.portal.show_message(
             "Wrong URL: %s" % self.request.getURL(), self.request, "warning"
