@@ -1,4 +1,3 @@
-# coding=utf-8
 from euphorie.client.authentication import addEuphorieAccountPlugin
 from euphorie.client.authentication import EuphorieAccountPlugin
 from plone import api
@@ -31,3 +30,5 @@ def setupVarious(context):
     pas = site.acl_users
     if not pas.objectIds([EuphorieAccountPlugin.meta_type]):
         add_account_plugin(pas)
+    ppr = api.portal.get_tool("portal_password_reset")
+    ppr.setExpirationTimeout(0.5)
