@@ -1,4 +1,3 @@
-# coding=utf-8
 from datetime import timedelta
 from euphorie.client import model
 from euphorie.client.tests.utils import addAccount
@@ -11,7 +10,7 @@ from plone.app.event.base import localized_now
 
 class TestDashboard(EuphorieIntegrationTestCase):
     def setUp(self):
-        super(TestDashboard, self).setUp()
+        super().setUp()
         self.loginAsPortalOwner()
         addSurvey(self.portal, BASIC_SURVEY)
         self.account = addAccount(password="secret")
@@ -101,11 +100,13 @@ class TestDashboard(EuphorieIntegrationTestCase):
         country = self.portal.client.nl
 
         with api.env.adopt_user(user=self.account):
-
             with self._get_view("portlet-my-ras", country) as view:
                 # The portlet by default hides the archived sessions
                 self.assertTrue(view.hide_archived)
-                self.assertEqual(len(view.sessions), 1)
+
+                self.assertEqual(
+                    len(view.sessions_by_organisation[self.account.organisation]), 1
+                )
 
                 view.request.__annotations__.clear()
 
@@ -113,14 +114,18 @@ class TestDashboard(EuphorieIntegrationTestCase):
                 # that by default is marked (we need and empty marker to check this)
                 view.request.set("hide_archived_marker", "1")
                 self.assertFalse(view.hide_archived)
-                self.assertEqual(len(view.sessions), 2)
+                self.assertEqual(
+                    len(view.sessions_by_organisation[self.account.organisation]), 2
+                )
 
                 view.request.__annotations__.clear()
 
                 # If the checbox is marked, the sessions are hidden again
                 view.request.set("hide_archived", "1")
                 self.assertTrue(view.hide_archived)
-                self.assertEqual(len(view.sessions), 1)
+                self.assertEqual(
+                    len(view.sessions_by_organisation[self.account.organisation]), 1
+                )
 
             with self._get_view("session-browser-sidebar", country) as view:
                 self.assertEqual(len(view.leaf_sessions()), 1)
