@@ -1,4 +1,3 @@
-# coding=utf-8
 from euphorie.client.tests.utils import addSurvey
 from euphorie.client.tests.utils import registerUserInClient
 from euphorie.testing import EuphorieFunctionalTestCase
@@ -41,6 +40,11 @@ class ProfileTests(EuphorieFunctionalTestCase):
             self.portal.client.nl["sector-title"]["survey-title"].absolute_url()
         )
         registerUserInClient(browser)
+        # We need to manually open the portlet view as the test browser
+        # does not handle JavaScript.
+        browser.open(
+            self.portal.client["nl"].absolute_url() + "/@@portlet-available-tools"
+        )
         # Create a new survey session
         browser.getControl(name="survey").value = ["sector-title/survey-title"]
         browser.getForm(action="new-session").submit()
@@ -127,9 +131,10 @@ class UpdateTests(EuphorieFunctionalTestCase):
     # This test is disabled because the queries used in copySessionData
     # are not compatible with SQLite.
     def XtestSkipChildrenFalseForMandatoryModules(self):
-        """Mandatory modules must have skip_children=False. It's possible that
-        the module was optional with skip_children=True and now after the
-        update must be mandatory.
+        """Mandatory modules must have skip_children=False.
+
+        It's possible that the module was optional with
+        skip_children=True and now after the update must be mandatory.
         """
         survey = """<sector xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
                       <title>Sector title</title>
