@@ -1,4 +1,3 @@
-# coding=utf-8
 from euphorie.client.tests.utils import addSurvey
 from euphorie.client.tests.utils import registerUserInClient
 from euphorie.testing import EuphorieFunctionalTestCase
@@ -19,12 +18,15 @@ class ReportTests(EuphorieFunctionalTestCase):
         browser = self.get_browser()
         browser.open(survey_url)
         registerUserInClient(browser)
+        # We need to manually open the portlet view as the test browser
+        # does not handle JavaScript.
+        browser.open(
+            self.portal.client["nl"].absolute_url() + "/@@portlet-available-tools"
+        )
         # Create a new survey session
         browser.getControl(name="survey").value = ["ict/software-development"]
         browser.getForm(action="new-session").submit()
-        browser.getControl(name="form.widgets.title").value = "Sessiøn".encode(
-            "utf-8"
-        )  # noqa
+        browser.getControl(name="form.widgets.title").value = "Sessiøn".encode()  # noqa
         # Start the survey
         browser.getControl(name="form.button.submit").click()
         session_url = browser.url.replace("/@@identification", "")
@@ -53,12 +55,15 @@ class ReportTests(EuphorieFunctionalTestCase):
         browser = self.get_browser()
         browser.open(survey_url)
         registerUserInClient(browser)
+        # We need to manually open the portlet view as the test browser
+        # does not handle JavaScript.
+        browser.open(
+            self.portal.client["nl"].absolute_url() + "/@@portlet-available-tools"
+        )
         # Create a new survey session
         browser.getControl(name="survey").value = ["ict/software-development"]
         browser.getForm(action="new-session").submit()
-        browser.getControl(name="form.widgets.title").value = "Sessiøn".encode(
-            "utf-8"
-        )  # noqa
+        browser.getControl(name="form.widgets.title").value = "Sessiøn".encode()  # noqa
         # Start the survey
         browser.getControl(name="form.button.submit").click()
         session_url = browser.url.replace("/@@identification", "")
@@ -75,12 +80,15 @@ class ReportTests(EuphorieFunctionalTestCase):
         survey_url = self.portal.client.nl["ict"]["software-development"].absolute_url()
         browser.open(survey_url)
         registerUserInClient(browser)
+        # We need to manually open the portlet view as the test browser
+        # does not handle JavaScript.
+        browser.open(
+            self.portal.client["nl"].absolute_url() + "/@@portlet-available-tools"
+        )
         # Create a new survey session
         browser.getControl(name="survey").value = ["ict/software-development"]
         browser.getForm(action="new-session").submit()
-        browser.getControl(name="form.widgets.title").value = "Sessiøn".encode(
-            "utf-8"
-        )  # noqa
+        browser.getControl(name="form.widgets.title").value = "Sessiøn".encode()  # noqa
         # Start the survey
         browser.getControl(name="form.button.submit").click()
         session_url = browser.url.replace("/@@identification", "")
