@@ -1,4 +1,3 @@
-# coding=utf-8
 from euphorie.client.tests.utils import addSurvey
 from euphorie.client.tests.utils import registerUserInClient
 from euphorie.content.tests.utils import BASIC_SURVEY
@@ -16,12 +15,15 @@ class RiskTests(EuphorieFunctionalTestCase):
         browser = self.get_browser()
         browser.open(survey.absolute_url())
         registerUserInClient(browser)
+        # We need to manually open the portlet view as the test browser
+        # does not handle JavaScript.
+        browser.open(
+            self.portal.client["nl"].absolute_url() + "/@@portlet-available-tools"
+        )
         # Create a new survey session
         browser.getControl(name="survey").value = ["ict/software-development"]
         browser.getForm(action="new-session").submit()
-        browser.getControl(name="form.widgets.title").value = "Sessiøn".encode(
-            "utf-8"
-        )  # noqa
+        browser.getControl(name="form.widgets.title").value = "Sessiøn".encode()  # noqa
         # Start the survey
         browser.getControl(name="form.button.submit").click()
         session_url = browser.url.replace("/@@identification", "")
@@ -44,10 +46,8 @@ class RiskTests(EuphorieFunctionalTestCase):
         self.assertEqual(browser.getControl(name="priority").value, ["high"])
 
     def XtestPreventEarlyDate(self):
-        """
-        Deactivated until we decide what to do about this kind of validation
-        error check
-        """
+        """Deactivated until we decide what to do about this kind of validation
+        error check."""
         # Test for http://code.simplon.biz/tracker/tno-euphorie/ticket/150
         self.loginAsPortalOwner()
         addSurvey(self.portal, BASIC_SURVEY)
@@ -57,12 +57,15 @@ class RiskTests(EuphorieFunctionalTestCase):
         ].absolute_url()  # noqa: E501
         browser.open(survey_url)
         registerUserInClient(browser)
+        # We need to manually open the portlet view as the test browser
+        # does not handle JavaScript.
+        browser.open(
+            self.portal.client["nl"].absolute_url() + "/@@portlet-available-tools"
+        )
         # Create a new survey session
         browser.getControl(name="survey").value = ["ict/software-development"]
         browser.getForm(action="new-session").submit()
-        browser.getControl(name="form.widgets.title").value = "Sessiøn".encode(
-            "utf-8"
-        )  # noqa
+        browser.getControl(name="form.widgets.title").value = "Sessiøn".encode()  # noqa
         # Start the survey
         browser.getControl(name="form.button.submit").click()
         # Identify the risk
@@ -93,10 +96,8 @@ class RiskTests(EuphorieFunctionalTestCase):
         self.assertTrue("Please enter a year between 2000 and 2100" in browser.contents)
 
     def Xtest_do_not_abort_on_far_future(self):
-        """
-        Deactivated, since such a far-future date can not be entered any more
-        in modern browsers
-        """
+        """Deactivated, since such a far-future date can not be entered any
+        more in modern browsers."""
         # Test for http://code.simplon.biz/tracker/tno-euphorie/ticket/150
         self.loginAsPortalOwner()
         addSurvey(self.portal, BASIC_SURVEY)
@@ -104,12 +105,15 @@ class RiskTests(EuphorieFunctionalTestCase):
         survey_url = self.portal.client.nl["ict"]["software-development"].absolute_url()
         browser.open(survey_url)
         registerUserInClient(browser)
+        # We need to manually open the portlet view as the test browser
+        # does not handle JavaScript.
+        browser.open(
+            self.portal.client["nl"].absolute_url() + "/@@portlet-available-tools"
+        )
         # Create a new survey session
         browser.getControl(name="survey").value = ["ict/software-development"]
         browser.getForm(action="new-session").submit()
-        browser.getControl(name="form.widgets.title").value = "Sessiøn".encode(
-            "utf-8"
-        )  # noqa
+        browser.getControl(name="form.widgets.title").value = "Sessiøn".encode()  # noqa
         # Start the survey
         browser.getControl(name="form.button.submit").click()
         # Identify the risk
@@ -144,12 +148,15 @@ class RiskTests(EuphorieFunctionalTestCase):
         ].absolute_url()  # noqa: E501
         browser.open(survey_url)
         registerUserInClient(browser)
+        # We need to manually open the portlet view as the test browser
+        # does not handle JavaScript.
+        browser.open(
+            self.portal.client["nl"].absolute_url() + "/@@portlet-available-tools"
+        )
         # Create a new survey session
         browser.getControl(name="survey").value = ["ict/software-development"]
         browser.getForm(action="new-session").submit()
-        browser.getControl(name="form.widgets.title").value = "Sessiøn".encode(
-            "utf-8"
-        )  # noqa
+        browser.getControl(name="form.widgets.title").value = "Sessiøn".encode()  # noqa
         # Start the survey
         browser.getControl(name="form.button.submit").click()
         session_url = browser.url.replace("/@@identification", "")
