@@ -1,4 +1,3 @@
-# coding=utf-8
 from AccessControl.PermissionRole import _what_not_even_god_should_do
 from datetime import timedelta
 from euphorie.client import config
@@ -14,7 +13,7 @@ from z3c.saconfig import Session
 try:
     from unittest import mock
 except ImportError:
-    import mock
+    from unittest import mock
 
 
 def createSurvey():
@@ -29,14 +28,13 @@ def createSurvey():
 
 class SurveySessionTests(EuphorieIntegrationTestCase):
     def test_iface(self):
-        """SurveySessions are marked by the ISurveySession interface"""
+        """SurveySessions are marked by the ISurveySession interface."""
         survey = createSurvey()[-1]
         self.assertTrue(model.ISurveySession.providedBy(survey))
 
     def test_is_archived(self):
-        """Verify that a session is archived when the archived attribute
-        is set and it is in the past
-        """
+        """Verify that a session is archived when the archived attribute is set
+        and it is in the past."""
         session = model.SurveySession()
         self.assertIsNone(session.archived)
         self.assertFalse(session.is_archived)
@@ -144,6 +142,19 @@ class SurveySessionTests(EuphorieIntegrationTestCase):
         ses.add(root)
         self.assertEqual(survey.hasTree(), True)
 
+    def test_absolute_url(self):
+        survey = createSurvey()[1]
+        with self.assertRaises(ValueError):
+            survey.absolute_url()
+
+        # We now set the zodb_path to something
+        # traversable in the context of the client folder
+        survey.zodb_path = ""
+
+        self.assertEqual(
+            survey.absolute_url(), "http://nohost/plone/client/++session++1"
+        )
+
 
 class RiskPresentFilterTests(EuphorieIntegrationTestCase):
     def createData(self):
@@ -284,26 +295,6 @@ class AccountTests(DatabaseTests):
         user = model.Account()
         self.assertEqual(user.has_permission("Euphorie: View a Survey", None), True)
 
-    def testNonLicetLoviNonLicetBovi(self):
-        user = model.Account()
-        self.assertEqual(user.allowed(None, _what_not_even_god_should_do), False)
-
-    def testHasAnonymousRole(self):
-        user = model.Account()
-        self.assertEqual(user.allowed(None, "Anonymous"), True)
-
-    def testHasAuthenticatedRole(self):
-        user = model.Account()
-        self.assertEqual(user.allowed(None, "Authenticated"), True)
-
-    def testHasEuphorieUserRole(self):
-        user = model.Account()
-        self.assertEqual(user.allowed(None, "EuphorieUser"), True)
-
-    def testNoOtherRole(self):
-        user = model.Account()
-        self.assertEqual(user.allowed(None, "Manager"), False)
-
     def testAccountType(self):
         (self.session, self.survey) = createSurvey()
         account = self.survey.account
@@ -415,8 +406,7 @@ class AccountTests(DatabaseTests):
 
     def testSessionAcquisition(self):
         """Users belonging to a group should be able to see all the sessions
-        belonging to the group and the group children
-        """
+        belonging to the group and the group children."""
         session = Session()
         group1 = model.Group(group_id="1")
         session.add(group1)
@@ -448,6 +438,34 @@ class AccountTests(DatabaseTests):
         self.assertListEqual(account2.acquired_sessions, [survey2])
 
 
+class AccountIntegrationTests(EuphorieIntegrationTestCase):
+    def setUp(self):
+        super().setUp()
+        self.allowed = model.Account().allowed
+        self.client = self.portal.client
+
+    def test_not_licet_iovi_not_licet_bovi(self):
+        self.assertFalse(self.allowed(self.client, _what_not_even_god_should_do))
+
+    def test_has_anonymous_role(self):
+        self.assertTrue(self.allowed(self.client, ["Anonymous"]))
+
+    def test_has_authenticated_role(self):
+        self.assertTrue(self.allowed(self.client, ["Authenticated"]))
+
+    def test_has_euphorie_user_role(self):
+        self.assertTrue(self.allowed(self.client, ["EuphorieUser"]))
+
+    def test_has_reader_role(self):
+        self.assertTrue(self.allowed(self.client, ["EuphorieUser"]))
+
+    def test_no_other_role(self):
+        self.assertFalse(self.allowed(self.client, ["Manager"]))
+
+    def test_has_no_reader_role_on_portal(self):
+        self.assertFalse(self.allowed(self.portal, ["Reader"]))
+
+
 class SurveySessionDBTests(DatabaseTests):
     def test_get_account_filter(self):
         session = model.SurveySession()
