@@ -1,4 +1,3 @@
-# coding=utf-8
 # from cStringIO import StringIO
 # from euphorie.client.report import HtmlToRtf
 # from euphorie.client.report import IdentificationReport
@@ -12,7 +11,7 @@ from euphorie.testing import EuphorieIntegrationTestCase
 from ExtensionClass import Base
 from plone import api
 from plone.app.testing.interfaces import SITE_OWNER_NAME
-from six.moves.urllib.parse import quote
+from urllib.parse import quote
 from z3c.saconfig import Session
 from zope.interface import alsoProvides
 
@@ -22,7 +21,7 @@ import datetime
 try:
     from unittest import mock
 except ImportError:
-    import mock
+    from unittest import mock
 
 
 # import unittest
@@ -251,14 +250,13 @@ class ReportIntegrationTests(EuphorieIntegrationTestCase):
 
 class ActionPlanTimelineTests(EuphorieIntegrationTestCase):
     def setUp(self):
-        super(ActionPlanTimelineTests, self).setUp()
+        super().setUp()
         self.account = addAccount(password="secret")
 
     def _get_timeline(self, context=None, request=None):
-        """Return the timeline view"""
+        """Return the timeline view."""
 
         class DummySurvey(mock.Mock, Base):
-
             __new__ = object.__new__
 
             def getPhysicalPath(self):
@@ -279,7 +277,7 @@ class ActionPlanTimelineTests(EuphorieIntegrationTestCase):
     def _create_session(self, dbsession=None):
         if dbsession is None:
             dbsession = Session()
-        session = SurveySession(account=self.account, zodb_path="survey")
+        session = SurveySession(account=self.account, zodb_path="test/dummy-survey")
         dbsession.add(session)
         dbsession.flush()
         return session
@@ -517,9 +515,9 @@ class ActionPlanTimelineTests(EuphorieIntegrationTestCase):
                 response.headers["content-type"],
                 "application/vnd.openxmlformats-" "officedocument.spreadsheetml.sheet",
             )
-            quoted_filename = quote("Timeline for Acmè.xlsx".encode("utf-8"))
+            quoted_filename = quote("Timeline for Acmè.xlsx".encode())
             self.assertEqual(quoted_filename, "Timeline%20for%20Acm%C3%A8.xlsx")
             self.assertEqual(
                 response.headers["content-disposition"],
-                "attachment; filename*=UTF-8''{}".format(quoted_filename),
+                f"attachment; filename*=UTF-8''{quoted_filename}",
             )
