@@ -1,4 +1,3 @@
-# coding: utf-8
 from euphorie.content.browser.export import ExportSurvey
 from euphorie.content.browser.upload import NSMAP
 from euphorie.content.module import Module
@@ -7,6 +6,7 @@ from euphorie.content.risk import Risk
 from euphorie.content.solution import Solution
 from euphorie.content.survey import Survey
 from euphorie.content.surveygroup import SurveyGroup
+from euphorie.content.training_question import TrainingQuestion
 from euphorie.testing import EuphorieIntegrationTestCase
 from io import BytesIO
 from lxml import etree
@@ -15,7 +15,7 @@ from zipfile import ZipFile
 from zope.publisher.browser import TestRequest
 
 
-class MockImage(object):
+class MockImage:
     def __init__(self, data, filename=None, contentType=None):
         self.data = data
         self.filename = filename
@@ -590,6 +590,28 @@ class ExportSurveyTests(EuphorieIntegrationTestCase):
             "</root>\n",
         )
 
+    def testTrainingQuestion(self):
+        training_question = TrainingQuestion()
+        training_question.title = "What is the answer?"
+        training_question.right_answer = "Yes"
+        training_question.wrong_answer_1 = "No"
+        training_question.wrong_answer_2 = "Maybe"
+        root = self.root()
+        view = ExportSurvey(None, None)
+        node = view.exportTrainingQuestion(root, training_question)
+        self.assertTrue(node in root)
+        self.assertEqual(
+            safe_nativestring(etree.tostring(root, pretty_print=True)),
+            '<root xmlns="http://xml.simplon.biz/euphorie/survey/1.0">\n'
+            "  <training_question>\n"
+            "    <title>What is the answer?</title>\n"
+            "    <right_answer>Yes</right_answer>\n"
+            "    <wrong_answer_1>No</wrong_answer_1>\n"
+            "    <wrong_answer_2>Maybe</wrong_answer_2>\n"
+            "  </training_question>\n"
+            "</root>\n",
+        )
+
     def testSurvey_Minimal(self):
         surveygroup = SurveyGroup()
         surveygroup.title = "Generic sector"
