@@ -1,5 +1,3 @@
-# coding=utf-8
-from ...ghost import PathGhost
 from ..fti import check_fti_paste_allowed
 from euphorie.content.fti import ConditionalDexterityFTI
 from euphorie.content.fti import IConstructionFilter
@@ -16,12 +14,12 @@ import unittest
 try:
     from unittest import mock
 except ImportError:
-    import mock
+    from unittest import mock
 
 
 @implementer(IConstructionFilter)
 @adapter(ConditionalDexterityFTI, Module)
-class Veto(object):
+class Veto:
     def __init__(self, fti, container):
         self.fti = fti
         self.container = container
@@ -32,7 +30,7 @@ class Veto(object):
 
 class ConditionalDexterityFTITests(EuphorieIntegrationTestCase):
     def setUp(self):
-        super(ConditionalDexterityFTITests, self).setUp()
+        super().setUp()
         self.loginAsPortalOwner()
 
     def _create(self, container, *args, **kwargs):
@@ -85,12 +83,6 @@ class check_fti_paste_allowed_tests(unittest.TestCase):
     def test_refuse_non_portal_content(self):
         self.assertRaises(ValueError, self.check_fti_paste_allowed, None, mock.Mock())
 
-    def test_do_not_use_acquisition_to_get_portal_type(self):
-        parent = PathGhost("parent")
-        parent.portal_type = "euphorie.risk"
-        content = PathGhost("child").__of__(parent)
-        self.assertRaises(ValueError, self.check_fti_paste_allowed, None, content)
-
     def test_content_without_fti(self):
         content = mock.Mock()
         content.portal_type = "euphorie.risk"
