@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from plone import api
 from plone.app.vocabularies.terms import safe_simplevocabulary_from_values
 from zope.interface import implementer
@@ -6,7 +5,7 @@ from zope.schema.interfaces import IContextSourceBinder
 
 
 @implementer(IContextSourceBinder)
-class RegistryValueVocabulary(object):
+class RegistryValueVocabulary:
     def __init__(self, value_name):
         self.value_name = value_name
 
