@@ -14,7 +14,6 @@ import logging
 import lxml.etree
 import lxml.objectify
 import os.path
-import six
 import sys
 import transaction
 import zExceptions
@@ -32,7 +31,7 @@ class Abort(RuntimeError):
 def GetCountry(plone, options):
     sectors = plone.sectors
     if not hasattr(sectors, options.country):
-        log.info("Creating missing country %s", options.country)
+        log.info("Creating missing country %r", options.country)
         sectors.invokeFactory(
             "euphorie.country", options.country, title=options.country
         )
@@ -69,12 +68,12 @@ def GetSector(country, xml_sector, options):
     if hasattr(xml_sector, "contact"):
         xml_contact = xml_sector.contact
         if hasattr(xml_contact, "name"):
-            sector.contact_name = six.text_type(xml_contact.name.text)
+            sector.contact_name = str(xml_contact.name.text)
         if hasattr(xml_contact, "email"):
-            sector.contact_email = six.text_type(xml_contact.email.text)
+            sector.contact_email = str(xml_contact.email.text)
     if options.logo is not None:
         sector.logo = NamedBlobImage(
-            data=open(options.logo, "r").read(),
+            data=open(options.logo).read(),
             filename=safe_unicode(os.path.basename(options.logo)),
         )
     if options.main_colour:
@@ -85,7 +84,7 @@ def GetSector(country, xml_sector, options):
 
 
 def ImportSector(plone, options, filename):
-    input = open(filename, "r")
+    input = open(filename)
     dom = lxml.objectify.parse(input)
     xml_sector = dom.getroot()
     country = GetCountry(plone, options)
@@ -102,12 +101,12 @@ def ImportSector(plone, options, filename):
     sm = getSecurityManager()
     try:
         newSecurityManager(None, sectoruser)
-        name = options.name or six.text_type(xml_sector.survey.title.text)
+        name = options.name or str(xml_sector.survey.title.text)
 
         if hasattr(sector, name):
             raise Abort("There is already a survey named '%s'" % name)
 
-        log.info("Importing survey '%s' with version '%s'", name, options.version)
+        log.info("Importing survey '%r' with version '%r'", name, options.version)
         importer = SurveyImporter(sector)
         survey = importer(xml_sector, name, options.version)
 
@@ -221,11 +220,11 @@ def main(app, args):
     for arg in args:
         transaction.begin()
         try:
-            log.info("Importing %s", arg)
+            log.info("Importing %r", arg)
             ImportSector(plone, options, arg)
             trans = transaction.get()
             trans.setUser("-commandline-")
-            trans.note("Import of %s" % arg)
+            trans.note("Import of %r" % arg)
             trans.commit()
         except lxml.etree.XMLSyntaxError as e:
             transaction.abort()
