@@ -1,9 +1,8 @@
-"""empty message
+"""Add a timestamp to the company table.
 
 Revision ID: 20210409113814
 Revises: 29
 Create Date: 2021-04-09 11:58:37.115736
-
 """
 from alembic import op
 
