@@ -1,9 +1,8 @@
-"""empty message
+"""Empty message.
 
 Revision ID: 27
 Revises: 26
 Create Date: 2020-03-04 10:51:17.559416
-
 """
 from alembic import op
 
